(function () {
  window.dropdown = 0;
var spellchecker = (function () {
  'use strict';

  var Cell = function (initial) {
    var value = initial;
    var get = function () {
      return value;
    };
    var set = function (v) {
      value = v;
    };
    var clone = function () {
      return Cell(get());
    };
    return {
      get: get,
      set: set,
      clone: clone
    };
  };

  var global = tinymce.util.Tools.resolve('tinymce.PluginManager');

  var hasProPlugin = function (editor) {
    if (/(^|[ ,])tinymcespellchecker([, ]|$)/.test(editor.settings.plugins) && global.get('tinymcespellchecker')) {
      if (typeof window.console !== 'undefined' && window.console.log) {
        window.console.log('Spell Checker Pro is incompatible with Spell Checker plugin! ' + 'Remove \'spellchecker\' from the \'plugins\' option.');
      }
      return true;
    } else {
      return false;
    }
  };
  var $_5fa0uxjljgqkx0oq = { hasProPlugin: hasProPlugin };

  var getLanguages = function (editor) {
    var defaultLanguages = 'English=en,Danish=da,Dutch=nl,Finnish=fi,French=fr_FR,German=de,Italian=it,Polish=pl,Portuguese=pt_BR,Spanish=es,Swedish=sv';
    return editor.getParam('spellchecker_languages', defaultLanguages);
  };
  var getLanguage = function (editor) {
    var defaultLanguage = editor.getParam('language', 'en');
    return editor.getParam('spellchecker_language', defaultLanguage);
  };
  var getRpcUrl = function (editor) {
    return editor.getParam('spellchecker_rpc_url');
  };
  var getSpellcheckerCallback = function (editor) {
    return editor.getParam('spellchecker_callback');
  };
  var getSpellcheckerWordcharPattern = function (editor) {
    var defaultPattern = new RegExp('[^' + '\\s!"#$%&()*+,-./:;<=>?@[\\]^_{|}`' + '\xA7\xA9\xAB\xAE\xB1\xB6\xB7\xB8\xBB' + '\xBC\xBD\xBE\xBF\xD7\xF7\xA4\u201D\u201C\u201E\xA0\u2002\u2003\u2009' + ']+', 'g');
    return editor.getParam('spellchecker_wordchar_pattern', defaultPattern);
  };
  var $_cklfqgjnjgqkx0ou = {
    getLanguages: getLanguages,
    getLanguage: getLanguage,
    getRpcUrl: getRpcUrl,
    getSpellcheckerCallback: getSpellcheckerCallback,
    getSpellcheckerWordcharPattern: getSpellcheckerWordcharPattern
  };

  var global$1 = tinymce.util.Tools.resolve('tinymce.util.Tools');

  var global$2 = tinymce.util.Tools.resolve('tinymce.util.URI');

  var global$3 = tinymce.util.Tools.resolve('tinymce.util.XHR');

  var fireSpellcheckStart = function (editor) {
    return editor.fire('SpellcheckStart');
  };
  var fireSpellcheckEnd = function (editor) {
    return editor.fire('SpellcheckEnd');
  };
  var $_4va4ocjsjgqkx0p5 = {
    fireSpellcheckStart: fireSpellcheckStart,
    fireSpellcheckEnd: fireSpellcheckEnd
  };

  function isContentEditableFalse(node) {
    return node && node.nodeType === 1 && node.contentEditable === 'false';
  }
  var DomTextMatcher = function (node, editor) {
    var m, matches = [], text;
    var dom = editor.dom;
    var blockElementsMap, hiddenTextElementsMap, shortEndedElementsMap;
    blockElementsMap = editor.schema.getBlockElements();
    hiddenTextElementsMap = editor.schema.getWhiteSpaceElements();
    shortEndedElementsMap = editor.schema.getShortEndedElements();
    function createMatch(m, data) {
      if (!m[0]) {
        throw new Error('findAndReplaceDOMText cannot handle zero-length matches');
      }
      return {
        start: m.index,
        end: m.index + m[0].length,
        text: m[0],
        data: data
      };
    }
    function getText(node) {
      var txt;
      if (node.nodeType === 3) {
        return node.data;
      }
      if (hiddenTextElementsMap[node.nodeName] && !blockElementsMap[node.nodeName]) {
        return '';
      }
      if (isContentEditableFalse(node)) {
        return '\n';
      }
      txt = '';
      if (blockElementsMap[node.nodeName] || shortEndedElementsMap[node.nodeName]) {
        txt += '\n';
      }
      if (node = node.firstChild) {
        do {
          txt += getText(node);
        } while (node = node.nextSibling);
      }
      return txt;
    }
    function stepThroughMatches(node, matches, replaceFn) {
      var startNode, endNode, startNodeIndex, endNodeIndex, innerNodes = [], atIndex = 0, curNode = node, matchLocation, matchIndex = 0;
      matches = matches.slice(0);
      matches.sort(function (a, b) {
        return a.start - b.start;
      });
      matchLocation = matches.shift();
      out:
        while (true) {
          if (blockElementsMap[curNode.nodeName] || shortEndedElementsMap[curNode.nodeName] || isContentEditableFalse(curNode)) {
            atIndex++;
          }
          if (curNode.nodeType === 3) {
            if (!endNode && curNode.length + atIndex >= matchLocation.end) {
              endNode = curNode;
              endNodeIndex = matchLocation.end - atIndex;
            // console.log("End:"+endNodeIndex);

            } else if (startNode) {
              innerNodes.push(curNode);
            }
            if (!startNode && curNode.length + atIndex > matchLocation.start) {
              startNode = curNode;
              startNodeIndex = matchLocation.start - atIndex;
              //console.log("Start:"+startNodeIndex);
            }
            atIndex += curNode.length;
          }
          if (startNode && endNode) {
            curNode = replaceFn({
              startNode: startNode,
              startNodeIndex: startNodeIndex,
              endNode: endNode,
              endNodeIndex: endNodeIndex,
              innerNodes: innerNodes,
              match: matchLocation.text,
              matchIndex: matchIndex
            });
            atIndex -= endNode.length - endNodeIndex;
            startNode = null;
            endNode = null;
            innerNodes = [];
            matchLocation = matches.shift();
            matchIndex++;
            if (!matchLocation) {
              break;
            }
          } else if ((!hiddenTextElementsMap[curNode.nodeName] || blockElementsMap[curNode.nodeName]) && curNode.firstChild) {
            if (!isContentEditableFalse(curNode)) {
              curNode = curNode.firstChild;
              continue;
            }
          } else if (curNode.nextSibling) {
            curNode = curNode.nextSibling;
            continue;
          }
          while (true) {
            if (curNode.nextSibling) {
              curNode = curNode.nextSibling;
              break;
            } else if (curNode.parentNode !== node) {
              curNode = curNode.parentNode;
            } else {
              break out;
            }
          }
        }
    }
    function genReplacer(callback) {
      function makeReplacementNode(fill, matchIndex) {
        var match = matches[matchIndex];
        if (!match.stencil) {
          match.stencil = callback(match);
        }
        var clone = match.stencil.cloneNode(false);
        clone.setAttribute('data-mce-index', matchIndex);
        if (fill) {
          clone.appendChild(dom.doc.createTextNode(fill));
        }
        return clone;
      }
      return function (range) {
        var before;
        var after;
        var parentNode;
        var startNode = range.startNode;
        var endNode = range.endNode;
        var matchIndex = range.matchIndex;
        var doc = dom.doc;
        if (startNode === endNode) {
          var node_1 = startNode;
          parentNode = node_1.parentNode;
          if (range.startNodeIndex > 0) {
            before = doc.createTextNode(node_1.data.substring(0, range.startNodeIndex));
            parentNode.insertBefore(before, node_1);
          }
          var el = makeReplacementNode(range.match, matchIndex);
          parentNode.insertBefore(el, node_1);
          if (range.endNodeIndex < node_1.length) {
            after = doc.createTextNode(node_1.data.substring(range.endNodeIndex));
            parentNode.insertBefore(after, node_1);
          }
          node_1.parentNode.removeChild(node_1);
          return el;
        }
        before = doc.createTextNode(startNode.data.substring(0, range.startNodeIndex));
        after = doc.createTextNode(endNode.data.substring(range.endNodeIndex));
        var elA = makeReplacementNode(startNode.data.substring(range.startNodeIndex), matchIndex);
        var innerEls = [];
        for (var i = 0, l = range.innerNodes.length; i < l; ++i) {
          var innerNode = range.innerNodes[i];
          var innerEl = makeReplacementNode(innerNode.data, matchIndex);
          innerNode.parentNode.replaceChild(innerEl, innerNode);
          innerEls.push(innerEl);
        }
        var elB = makeReplacementNode(endNode.data.substring(0, range.endNodeIndex), matchIndex);
        parentNode = startNode.parentNode;
        parentNode.insertBefore(before, startNode);
        parentNode.insertBefore(elA, startNode);
        parentNode.removeChild(startNode);
        parentNode = endNode.parentNode;
        parentNode.insertBefore(elB, endNode);
        parentNode.insertBefore(after, endNode);
        parentNode.removeChild(endNode);
        return elB;
      };
    }
    function unwrapElement(element) {
      var parentNode = element.parentNode;
      parentNode.insertBefore(element.firstChild, element);
      element.parentNode.removeChild(element);
    }
    function hasClass(elm) {
      return elm.className.indexOf('mce-spellchecker-word') !== -1;
    }
    function getWrappersByIndex(index) {
      var elements = node.getElementsByTagName('*'), wrappers = [];
      index = typeof index === 'number' ? '' + index : null;
      for (var i = 0; i < elements.length; i++) {
        var element = elements[i], dataIndex = element.getAttribute('data-mce-index');
        if (dataIndex !== null && dataIndex.length && hasClass(element)) {
          if (dataIndex === index || index === null) {
            wrappers.push(element);
          }
        }
      }
      return wrappers;
    }
    function indexOf(match) {
      var i = matches.length;
      while (i--) {
        if (matches[i] === match) {
          return i;
        }
      }
      return -1;
    }
    function filter(callback) {
      var filteredMatches = [];
      each(function (match, i) {
        if (callback(match, i)) {
          filteredMatches.push(match);
        }
      });
      matches = filteredMatches;
      return this;
    }
    function each(callback) {
      for (var i = 0, l = matches.length; i < l; i++) {
        if (callback(matches[i], i) === false) {
          break;
        }
      }
      return this;
    }
    function wrap(callback) {
      if (matches.length) {
        stepThroughMatches(node, matches, genReplacer(callback));
      }
      return this;
    }
    function find(regex, data) {
      if (text && regex.global) {
        while (m = regex.exec(text)) {
          matches.push(createMatch(m, data));
        }
      }
      return this;
    }
    function unwrap(match) {
      var i;
      var elements = getWrappersByIndex(match ? indexOf(match) : null);
      i = elements.length;
      while (i--) {
        unwrapElement(elements[i]);
      }
      return this;
    }
    function matchFromElement(element) {
      return matches[element.getAttribute('data-mce-index')];
    }
    function elementFromMatch(match) {
      return getWrappersByIndex(indexOf(match))[0];
    }
    function add(start, length, data) {
      matches.push({
        start: start,
        end: start + length,
        text: text.substr(start, length),
        data: data
      });
      return this;
    }
    function rangeFromMatch(match) {
      var wrappers = getWrappersByIndex(indexOf(match));
      var rng = editor.dom.createRng();
      rng.setStartBefore(wrappers[0]);
      rng.setEndAfter(wrappers[wrappers.length - 1]);
      return rng;
    }
    function replace(match, text) {
      var rng = rangeFromMatch(match);
      rng.deleteContents();
      if (text.length > 0) {
        rng.insertNode(editor.dom.doc.createTextNode(text));
      }
      return rng;
    }
    function reset() {
      matches.splice(0, matches.length);
      unwrap();
      return this;
    }
    text = getText(node);
    return {
      text: text,
      matches: matches,
      each: each,
      filter: filter,
      reset: reset,
      matchFromElement: matchFromElement,
      elementFromMatch: elementFromMatch,
      find: find,
      add: add,
      wrap: wrap,
      unwrap: unwrap,
      replace: replace,
      rangeFromMatch: rangeFromMatch,
      indexOf: indexOf
    };
  };

  var getTextMatcher = function (editor, textMatcherState) {
    if (!textMatcherState.get()) {
      var textMatcher = DomTextMatcher(editor.getBody(), editor);
     // console.log(editor.getBody());
      textMatcherState.set(textMatcher);
    }
    return textMatcherState.get();
  };
  var isEmpty = function (obj) {
    for (var _ in obj) {
      return false;
    }
    return true;
  };
  var defaultSpellcheckCallback = function (editor, pluginUrl, currentLanguageState) {
    return function (method, text, doneCallback, errorCallback) {
      var data = {
        method: method,
        lang: currentLanguageState.get()
      };
      var postData = '';
      data[method === 'addToDictionary' ? 'word' : 'text'] = text;
      global$1.each(data, function (value, key) {
        if (postData) {
          postData += '&';
        }
        postData += key + '=' + encodeURIComponent(value);
      });
      global$3.send({
        url: new global$2(pluginUrl).toAbsolute($_cklfqgjnjgqkx0ou.getRpcUrl(editor)),
        type: 'post',
        content_type: 'application/x-www-form-urlencoded',
        data: postData,
        success: function (result) {
          result = JSON.parse(result);
          if (!result) {
            var message = editor.translate('Server response wasn\'t proper JSON.');
            errorCallback(message);
          } else if (result.error) {
            errorCallback(result.error);
          } else {
            doneCallback(result);
          }
        },
        error: function () {
          var message = editor.translate('The spelling service was not found: (') + $_cklfqgjnjgqkx0ou.getRpcUrl(editor) + editor.translate(')');
          errorCallback(message);
        }
      });
    };
  };
  var sendRpcCall = function (editor, pluginUrl, currentLanguageState, name, data, successCallback, errorCallback) {
    var userSpellcheckCallback = $_cklfqgjnjgqkx0ou.getSpellcheckerCallback(editor);
    var spellCheckCallback = userSpellcheckCallback ? userSpellcheckCallback : defaultSpellcheckCallback(editor, pluginUrl, currentLanguageState);
    spellCheckCallback.call(editor.plugins.spellchecker, name, data, successCallback, errorCallback);
  };
  var spellcheck = function (editor, pluginUrl, startedState, textMatcherState, lastSuggestionsState, currentLanguageState) {
    if (finish(editor, startedState, textMatcherState)) {
      return;
    }
    var errorCallback = function (message) {
     /* editor.notificationManager.open({
        text: message,
        type: 'error'
      });*/
      editor.setProgressState(false);
      finish(editor, startedState, textMatcherState);
    };
    var successCallback = function (data) {
      markErrors(editor, startedState, textMatcherState, lastSuggestionsState, data);
    };
    editor.setProgressState(true);
    sendRpcCall(editor, pluginUrl, currentLanguageState, 'spellcheck', getTextMatcher(editor, textMatcherState).text, successCallback, errorCallback);
    editor.focus();
  };
  var checkIfFinished = function (editor, startedState, textMatcherState) {
    if (!editor.dom.select('span.mce-spellchecker-word').length) {
      finish(editor, startedState, textMatcherState);
    }
  };
  var addToDictionary = function (editor, pluginUrl, startedState, textMatcherState, currentLanguageState, word, spans) {
    editor.setProgressState(true);
    sendRpcCall(editor, pluginUrl, currentLanguageState, 'addToDictionary', word, function () {
      editor.setProgressState(false);
      editor.dom.remove(spans, true);
      checkIfFinished(editor, startedState, textMatcherState);
    }, function (message) {
      editor.notificationManager.open({
        text: message,
        type: 'error'
      });
      editor.setProgressState(false);
    });
  };
  var ignoreWord = function (editor, startedState, textMatcherState, word, spans, all) {
    editor.selection.collapse();
    if (all) {
      global$1.each(editor.dom.select('span.mce-spellchecker-word'), function (span) {
        if (span.getAttribute('data-mce-word') === word) {
          editor.dom.remove(span, true);
        }
      });
    } else {
      editor.dom.remove(spans, true);
    }
    checkIfFinished(editor, startedState, textMatcherState);
  };
  var finish = function (editor, startedState, textMatcherState) {
    getTextMatcher(editor, textMatcherState).reset();
    textMatcherState.set(null);
    if (startedState.get()) {
      startedState.set(false);
      $_4va4ocjsjgqkx0p5.fireSpellcheckEnd(editor);
      return true;
    }
  };
  var getElmIndex = function (elm) {
    var value = elm.getAttribute('data-mce-index');
    if (typeof value === 'number') {
      return '' + value;
    }
    return value;
  };
  var findSpansByIndex = function (editor, index) {
    var nodes;
    var spans = [];
    nodes = global$1.toArray(editor.getBody().getElementsByTagName('span'));
    if (nodes.length) {
      for (var i = 0; i < nodes.length; i++) {
        var nodeIndex = getElmIndex(nodes[i]);
        if (nodeIndex === null || !nodeIndex.length) {
          continue;
        }
        if (nodeIndex === index.toString()) {
          spans.push(nodes[i]);
        }
      }
    }
    return spans;
  };
  var markErrors = function (editor, startedState, textMatcherState, lastSuggestionsState, data) {
    var suggestions, hasDictionarySupport;

    if (typeof data !== 'string' && data.words) {
      hasDictionarySupport = !!data.dictionary;
      suggestions = data.words;
    } else {
      suggestions = data;
    }
   // console.log(suggestions);
    editor.setProgressState(false);
    if (isEmpty(suggestions)) {
      /*var message = editor.translate('No misspellings found.');
      editor.notificationManager.open({
        text: message,
        type: 'info'
      });*/
      console.log("test");

     // startedState.set(false);
      //return;
    }
    lastSuggestionsState.set({
      suggestions: suggestions,
      hasDictionarySupport: hasDictionarySupport
    });
    getTextMatcher(editor, textMatcherState).find($_cklfqgjnjgqkx0ou.getSpellcheckerWordcharPattern(editor)).filter(function (match) {
      return !!suggestions[match.text];
    }).wrap(function (match) {
      return editor.dom.create('span', {
        'class': 'mce-spellchecker-word',
        'data-mce-bogus': 1,
        'data-mce-word': match.text
      });
    });
    startedState.set(true);
    $_4va4ocjsjgqkx0p5.fireSpellcheckStart(editor);
    editor.selection.moveToBookmark(editor.selection.getBookmark());

   // editor.dom.remove(span, true);
  };
  var $_cef0v7jojgqkx0oz = {
    spellcheck: spellcheck,
    checkIfFinished: checkIfFinished,
    addToDictionary: addToDictionary,
    ignoreWord: ignoreWord,
    findSpansByIndex: findSpansByIndex,
    getElmIndex: getElmIndex,
    markErrors: markErrors
  };

  var get = function (editor, startedState, lastSuggestionsState, textMatcherState, currentLanguageState, url) {
    var getLanguage = function () {
      return currentLanguageState.get();
    };
    var getWordCharPattern = function () {
      return $_cklfqgjnjgqkx0ou.getSpellcheckerWordcharPattern(editor);
    };
    var markErrors = function (data) {
      $_cef0v7jojgqkx0oz.markErrors(editor, startedState, textMatcherState, lastSuggestionsState, data);
    };
    var getTextMatcher = function () {
      return textMatcherState.get();
    };
    return {
      getTextMatcher: getTextMatcher,
      getWordCharPattern: getWordCharPattern,
      markErrors: markErrors,
      getLanguage: getLanguage
    };
  };
  var $_44cb15jmjgqkx0os = { get: get };

  var register = function (editor, pluginUrl, startedState, textMatcherState, lastSuggestionsState, currentLanguageState) {
    editor.addCommand('mceSpellCheck', function () {
      $_cef0v7jojgqkx0oz.spellcheck(editor, pluginUrl, startedState, textMatcherState, lastSuggestionsState, currentLanguageState);
    });
  };
  var $_3adfryjujgqkx0pl = { register: register };

  var buildMenuItems = function (listName, languageValues) {
    var items = [];
    global$1.each(languageValues, function (languageValue) {
      items.push({
        selectable: true,
        text: languageValue.name,
        data: languageValue.value
      });
    });
    return items;
  };
  var updateSelection = function (editor, currentLanguageState) {
    return function (e) {
      var selectedLanguage = currentLanguageState.get();
      e.control.items().each(function (ctrl) {
        ctrl.active(ctrl.settings.data === selectedLanguage);
      });
    };
  };
  var getItems = function (editor) {
    return global$1.map($_cklfqgjnjgqkx0ou.getLanguages(editor).split(','), function (langPair) {
      langPair = langPair.split('=');
      return {
        name: langPair[0],
        value: langPair[1]
      };
    });
  };
  var register$1 = function (editor, pluginUrl, startedState, textMatcherState, currentLanguageState, lastSuggestionsState) {
    var languageMenuItems = buildMenuItems('Language', getItems(editor));
    var startSpellchecking = function () {
      window.ccspc = true;
      $_cef0v7jojgqkx0oz.spellcheck(editor, pluginUrl, startedState, textMatcherState, lastSuggestionsState, currentLanguageState);
    };

    var buttonArgs = {
      tooltip: 'Spellcheck',
      onclick: startSpellchecking,
      onPostRender: function (e) {
        var ctrl = e.control;
        editor.on('SpellcheckStart SpellcheckEnd', function () {
          ctrl.active(startedState.get());
        });
      }
    };
    if (languageMenuItems.length > 1) {
      buttonArgs.type = 'splitbutton';
      buttonArgs.menu = languageMenuItems;
      buttonArgs.onshow = updateSelection(editor, currentLanguageState);
      buttonArgs.onselect = function (e) {
        currentLanguageState.set(e.control.settings.data);
      };
    }

    // Coll Similar to original editor.addButton('spellchecker', buttonArgs);
    editor.addMenuItem('spellchecker', {
      text: 'Suggest Collocations', // CD£ Button text
      tooltip: 'Suggest Collocations', //CD£ Tooltip
      context: 'tools',
      onclick: startSpellchecking,
      selectable: true,
      onPostRender: function () {
        console.log("collocations post render")
        var self = this;
        self.active(startedState.get());
        editor.on('SpellcheckStart SpellcheckEnd', function () {
          self.active(startedState.get());
          console.log(startedState.get());
        });
      }
    });
    
    editor.addMenuItem('dropdown', {
      text: 'In-Text View',
      tooltip: 'In-Text View', //CD£ Tooltip
      context: 'tools',
      onclick: function () {
        var btn = this;
        if(dropdown==1) { 
          dropdown=0;
          btn.active(false);
    	  } else {
    	    dropdown=1;
          btn.active(true);
          
        }
      },
      selectable: true,
      onPostRender: function () {
        console.log("dropdown post render")
        var self = this;
        self.active(startedState.get());
        // console.log("STARTED STATE", startedState.get())
        self.disabled(!startedState.get());
        editor.on('SpellcheckStart SpellcheckEnd', function () {
          self.disabled(!startedState.get());
          self.active(startedState.get())
        });
        // dropdown = 0 ? self.active(false) : self.active(true);
        // self.active(false);
      }
    });
    
    editor.addMenuItem('vispanel', {
     text: 'Tree View',
      tooltip: 'Tree View', //CD£ Tooltip
      context: 'tools',
      onclick: function () {
        var btn = this;
        if(window.getComputedStyle(document.querySelector("#collocaid-vis")).display === "none" || document.querySelector("#collocaid-vis").style.display === "none") { 
          document.querySelector('#collocaid-vis').style.display = "block";
          document.querySelector('#container').style.width = "100%";
          document.querySelector('#container').style.marginLeft = "0px";
          document.querySelector('#container').style.marginRight = "0px";

          // btn.active(true);
    	  } else {
          document.querySelector('#collocaid-vis').style.display = "none";
          document.querySelector('#container').style.width = "1000px";
          document.querySelector('#container').style.marginLeft = "auto";
          document.querySelector('#container').style.marginRight = "auto";
          // btn.active(false);
        dropdown = 0;
      }},
      selectable: true,
      onPostRender: function () {
        console.log("vispanel post render")

        var self = this;
        self.disabled(!startedState.get());
        editor.on('SpellcheckStart SpellcheckEnd', function () {
          self.disabled(!startedState.get());
        });
        // self.active(false);
      }
    });
    
    editor.addMenuItem('save1', {
      text: 'Download as .txt',
      tooltip: 'Download as .txt', //CD£ Tooltip
      context: 'tools',
      onclick: function () {
     var btn = this;
     console.log('saving...');

     function downloadString(text, fileType, fileName) {
       var blob = new Blob([text], { type: fileType });
     
       var a = document.createElement('a');
       a.download = fileName;
       a.href = URL.createObjectURL(blob);
       a.dataset.downloadurl = [fileType, a.download, a.href].join(':');
       a.style.display = "none";
       document.body.appendChild(a);
       a.click();
       document.body.removeChild(a);
       setTimeout(function() { URL.revokeObjectURL(a.href); }, 1500);
     }

     let tmp = document.createElement('div');
     tmp.innerHTML = window.tinyMCE.activeEditor.getContent();

     downloadString(tmp.innerText.trim(), 'txt', 'collocaid-download');
    },
      selectable: true,
      onPostRender: function () {
       var self = this;
       
     }
    });
    /*
     editor.addButton('collocaidbutton', {
      type: 'menubutton',
      text: 'ColloCaid',
      icon: false,
      menu: [{
       text: 'Collocation suggestions', // CD£ Button text
      tooltip: 'Collocation suggestions', //CD£ Tooltip
      context: 'tools',
      onclick: startSpellchecking,
      selectable: true,
       onPostRender: function () {
        var self = this;
        self.active(startedState.get());
        editor.on('SpellcheckStart SpellcheckEnd', function () {
          self.active(startedState.get());
          console.log(startedState.get());
        });
      }
      }, 
      {
        text: 'Toggle Dropdown',
        tooltip: 'Toggle Dropdown', //CD£ Tooltip
      context: 'tools',
      onclick: function () {
     var btn = this;
     if(dropdown==1)
       { 
       dropdown=0;
       btn.active(false);
    	}
    else 
    	{
    	dropdown=1;
    	btn.active(true);
      }},
      selectable: true,
      onPostRender: function () {
       var self = this;
       
       self.active(true);
       
     }
      },
      {
        text: 'Visualisation panel',
        tooltip: 'Visualisation panel', //CD£ Tooltip
      context: 'tools',
       onclick: function () {
     var btn = this;
     if(window.getComputedStyle(document.querySelector("#collocaid-vis")).display === "none" || document.querySelector("#collocaid-vis").style.display === "none")
       { 
       document.querySelector('#collocaid-vis').style.display = "block";
       btn.active(true);
    	}
    else 
    	{
    	document.querySelector('#collocaid-vis').style.display = "none";
    	btn.active(false);
      }},
      selectable: true,
      onPostRender: function () {
       var self = this;
       
       self.active(false);
       
     }
      }
      ]
    });
    
    editor.addButton('spellbutton', {
   active: true,
     text: 'ColloCaid',
     onAction: startSpellchecking,
      onclick: startSpellchecking,
     selectable: true,
      onPostRender: function () {
       var self = this;
       self.active(1);
       editor.on('SpellcheckStart SpellcheckEnd', function () {
         self.active(startedState.get());
         console.log(startedState.get());
       });
     }
   }); 
    editor.addButton('visbutton', {
   active: true,
     text: 'ColloCaid Vis',
     onclick: function () {
     var btn = this;
     if(window.getComputedStyle(document.querySelector("#collocaid-vis")).display === "none" || document.querySelector("#collocaid-vis").style.display === "none")
       { 
       document.querySelector('#collocaid-vis').style.display = "block";
       btn.active(true);
    	}
    else 
    	{
    	document.querySelector('#collocaid-vis').style.display = "none";
    	btn.active(false);
      }},
     selectable: true,
      onPostRender: function () {
       var self = this;
       
       self.active(false);
       
     }
      
   });
   
    editor.addButton('dropdownbutton', {
   active: true,
     text: 'Dropdown',
     onclick: function () {
     var btn = this;
     if(dropdown==1)
       { 
       dropdown=0;
       btn.active(false);
    	}
    else 
    	{
    	dropdown=1;
    	btn.active(true);
      }},
     selectable: true,
      onPostRender: function () {
       var self = this;
       
       self.active(true);
       
     }
      
   });
   */
    var coldstart=0;
    editor.on('keypress', function(e) {  //console.log("Enter");

    //console.log(startedState.get());
    //console.log(myObj);


    var key = e.which || e.keyCode || 0;
    //
 // console.log(key);
   if ( key == 32 // SPACE
            || key == 44  // , Comma
             || key == 8 // backspace
             || key == 9 //Enter
             || key ==13 //Tab
        )
   {
       editor.selection.moveToBookmark(editor.selection.getBookmark());
//console.log("keypress");
   if(!coldstart)
    {
     if(startedState.get())
     {
     //console.log(startedState.get());
    coldstart++;
     }
     else
     {
      startSpellchecking();
     // console.log(startedState.get());
      }
    }
  // console.log(key);
   //editor.fire('SpellcheckStart');
   if(startedState.get())
   {
     startSpellchecking();
      startSpellchecking();
}
   }
   // $_5sbzqxjojh9pyfx2.spellcheck(editor, pluginUrl, startedState, textMatcherState, lastSuggestionsState, currentLanguageState);

     });
     editor.on('paste', function(e)
     {
     //console.log(e);
       if(startedState.get())
   {
      //console.log("check");
     startSpellchecking();
      startSpellchecking();
}

     });

  };
  var $_8x3bpjjvjgqkx0px = { register: register$1 };

  var global$4 = tinymce.util.Tools.resolve('tinymce.dom.DOMUtils');

  var global$5 = tinymce.util.Tools.resolve('tinymce.ui.Factory');

  var suggestionsMenu;
   function clearmenu()
 {
 if(suggestionsMenu !=null)
      	{
      	suggestionsMenu.remove();
        suggestionsMenu = null;
      	}
 }
  var showSuggestions = function (editor, pluginUrl, lastSuggestionsState, startedState, textMatcherState, currentLanguageState, word, spans) {
    var items = [], suggestions = lastSuggestionsState.get().suggestions[word],visobj=[],moreobj=[];
    // CD£ variables
      var collocate=[], collocate_obj=[];
      var pos=[], relations=[];
     var longest_matches=[];
           var examples=[];
      var collocate_obj2=[];
    var collocate_menu_global=[];
    var subject_of=[], object_of=[],modifier=[],preposition=[];
    var advv=[],prep=[],vadv=[];
    var advadj=[],prepad=[];
      var collocate_menu=[];
      var collocate_menu1=[];
      var collocate_menu2=[];
      var longest_match_menu=[];
      var senses_menun=[];
      var senses_menuv=[];
      var example_menu=[],flag=[];
        var timer;
        var clicks=0;
        word=word.toLowerCase();
    var pos= allwords[dbwords.indexOf(word)].POS;
    var lemma=allwords[dbwords.indexOf(word)].lemma;
    var base=allwords[dbwords.indexOf(word)].Base.toLowerCase();
    var lemmatisation;
var additionaltext;
var allcoll;

var myTable = document.getElementById('tableID');



var myDiv = document.getElementById('info');
//myDiv.style.borderStyle = "solid";
//myDiv.innerHTML = variableLongText;
myDiv.scrollTop = 0;
function lemmaPOSvalues(array, searchItem) {
  var i = array.indexOf(searchItem),
      indexes = [];
  while (i !== -1) {
    indexes.push(allwords[i].POS);
    i = array.indexOf(searchItem, ++i);
  }
  return indexes;
}

if (lemma!=base)
lemmatisation=1;
    var lemmaPOS=lemmaPOSvalues(dbwords,word);
    // console.log(lemmaPOS);
//additionaltext="<table class='moreoptions morecoll' id=\'tableID\'> <thead><tr><th>Collocate</th>   </tr></thead>";
additionaltext="<table class='moreoptions morecoll' id=\'tableID\'> ";

//    console.log(additionaltext);

var selected_collocates=collocations.filter(function(item){
/*if(typeof item.Base === "boolean")
{	console.log( item.ID);
	console.log(item.Base=="true");
}*/
    return item.Base==lemma;
}); //filter collocates for this keyword
//console.log(selected_collocates);

function divScroll() {
    document.getElementById("info").scrollTop += 1;
    //window.scrollBy(0,1);
    scrolldelay = setTimeout(divScroll,10);
}


function convertto (example,original,stemmed,flag)
{

 var regex = new RegExp('\\b' + original + '\\b');
 //console.log(example.search(regex));
var examplearr=example.split(" ");
var examplefiltered;

if(example.search(regex)>=0)
examplefiltered= original;
else
examplefiltered=examplearr.filter(word =>(word.indexOf(original)>=0)? word.indexOf(original)>=0:word.indexOf(stemmed)>=0);

if(flag)
{
return example.replace(examplefiltered, "<b>"+examplefiltered+"</b>");
}
else
{
return example.replace(examplefiltered, examplefiltered.toString().toUpperCase());
}

//return examplefiltered;
}

function skellurl(collocate)
{
var converted=collocate;

switch (collocate)
{

  case "focuses":
    converted = "focus";
    break;
  case "discusses":
    converted = "discuss";
    break;
  case "encompasses":
    converted = "encompass";
    break;
  case "accompanies":
    converted = "accompany";
    break;
  case "does":
    converted = "do";
    break;
  case "pushes":
    converted = "push";
    break;
  case "satisfies":
    converted = "satisfy";
    break;
  case "possesses":
    converted = "possess";
    break;
 case "addresses":
    converted = "address";
    break;
  case "has":
    converted = "have";
    break;
  case "establishes":
    converted = "establish";
    break;
  case "expresses":
    converted = "express";
    break;
  case "completes":
    converted = "complete";
    break;
  case "assesses":
    converted = "assess";
    break;
  case "signifies":
    converted = "signify";

  default:
  if(collocate.slice(collocate.length -1)=="s")
		{ //console.log("B:"+converted);
		 	converted= collocate.slice(0, -1);
 			//console.log("A:"+converted);
			}
    else
	  converted = collocate;

	break;
}

return converted;
}
selected_collocates.forEach(function (element, index, array){
//element.SENSE_DISAMBIGUATION ? console.log("Sense: "+element.SENSE_DISAMBIGUATION) : null;
//var examplearr1=element.EXAMPLE1.split(" ");
//var examplearr2=element.EXAMPLE2.split(" ");
//var examplearr3=element.EXAMPLE3.split(" ");

var collocate=element.COLLOCATE.toString().toLowerCase();
var base=element.Base.toLowerCase();
var stemcollocate=element.COLLOCATESTEM;
var stembase=element.BASESTEM;

//console.log(stemcollocate+stembase);
//var collocate1 = examplearr1.filter(word =>(word.indexOf(collocate)>=0)? word.indexOf(collocate)>=0:word.indexOf(stemcollocate)>=0);
//var base1 = examplearr1.filter(word =>(word.indexOf(base)>=0)? word.indexOf(base)>=0:word.indexOf(stembase)>=0);

//var collocate2 = examplearr2.filter(word =>(word.indexOf(collocate)>=0)? word.indexOf(collocate)>=0:word.indexOf(stemcollocate)>=0);
//var base2 = examplearr2.filter(word =>(word.indexOf(base)>=0)? word.indexOf(base)>=0:word.indexOf(stembase)>=0);
//var collocate3 = examplearr3.filter(word =>(word.indexOf(collocate)>=0)? word.indexOf(collocate)>=0:word.indexOf(stemcollocate)>=0);
//var base3 = examplearr3.filter(word =>(word.indexOf(base)>=0)? word.indexOf(base)>=0:word.indexOf(stembase)>=0);

//console.log(collocate3+base3);
//element.EXAMPLE1= element.EXAMPLE1.toLowerCase();

var example1=convertto(element.EXAMPLE1,collocate,stemcollocate,1);
var example2=convertto(element.EXAMPLE2,collocate,stemcollocate,1);
var example3=convertto(element.EXAMPLE3,collocate,stemcollocate,1);
example1 =convertto(example1,base,stembase,1);
example2 =convertto(example2,base,stembase,1);
example3 =convertto(example3,base,stembase,1);
//console.log(example1+example2);
/*
//var text=element1.replace(element.Base, element.Base.toUpperCase());
element.EXAMPLE1=element.EXAMPLE1.replace(collocate1, collocate1.toString().toUpperCase());
element.EXAMPLE2=element.EXAMPLE2.replace(collocate2, collocate2.toString().toUpperCase());
element.EXAMPLE3=element.EXAMPLE3.replace(collocate3, collocate3.toString().toUpperCase());

element.EXAMPLE1=element.EXAMPLE1.replace(base1, base1.toString().toUpperCase());
element.EXAMPLE2=element.EXAMPLE2.replace(base2, base2.toString().toUpperCase());
element.EXAMPLE3=element.EXAMPLE3.replace(base3, base3.toString().toUpperCase());
*/

/** OLD SE API REFACTOR NECESSARY */

// if(element.RELATION=="subject_of")
// {
// additionaltext+="<tr class='moreoptions subject_of'> <td   onClick=\"inserttext('"+base+ " " +collocate+"'); \" >"+base+ " " +collocate+"<td ><a class='caret' href='https://skell.sketchengine.co.uk/run.cgi/wordsketch_concordance?headword="+base+ "-n;gramrel=verbs%20with%20%w%20as%20subject;coll=" +skellurl(collocate)+"-v'target='_blank'>▶</a> </td>";


// moreobj.push({
// 	submenu:element.RELATION,
//     text: base+ " " +collocate,
//     url: 'https://skell.sketchengine.co.uk/run.cgi/wordsketch_concordance?headword='+base+ '-n;gramrel=verbs%20with%20%w%20as%20subject;coll=' +skellurl(collocate)+'-v',
//   });
// }
// else if (element.RELATION=="object_of")
// {
// additionaltext+="<tr class='moreoptions object_of'> <td id='test'  onClick=\"inserttext('"+collocate+ " " +base+"'); \" >"+collocate+ " " +base+"<td ><a href='https://skell.sketchengine.co.uk/run.cgi/wordsketch_concordance?headword="+base+ "-n;gramrel=verbs%20with%20%w%20as%20object;coll=" +collocate+"-v'target='_blank'>▶</a> </td>";
// moreobj.push({
// 	submenu:element.RELATION,
//     text: collocate+ " " +base,
//     url:'https://skell.sketchengine.co.uk/run.cgi/wordsketch_concordance?headword='+ base+ "-n;gramrel=verbs%20with%20%w%20as%20object;coll=" +collocate+"-v",
//   });

// }
//  else if (element.RELATION=="modifier")
// {
// 	additionaltext+="<tr class='moreoptions modifier'> <td id='test'  onClick=\"inserttext('"+collocate+ " " +base+"'); \" >"+collocate+ " " +base+"<td ><a href='https://skell.sketchengine.co.uk/run.cgi/wordsketch_concordance?headword="+base+ "-n;gramrel=modifiers%20of%20%w;coll=" +collocate+"-j'target='_blank'>▶</a> </td>";
//  	moreobj.push({
// 	submenu:element.RELATION,
//     text: collocate+ " " +base,
//     url: 'https://skell.sketchengine.co.uk/run.cgi/wordsketch_concordance?headword='+base+ "-n;gramrel=modifiers%20of%20%w;coll=" +collocate+"-j",
//   	});
//  }
//  else if(element.RELATION=="preposition"&& element.POS=="n")
//  {
// 	 additionaltext+="<tr class='moreoptions'> <td id='test'  onClick=\"inserttext('"+base+ " " +collocate+" " +element.COLLOCATE_OF_PREP+"'); \" >"+base+ " " +collocate+" " +element.COLLOCATE_OF_PREP+"<td ><a href='https://skell.sketchengine.co.uk/run.cgi/concordance?lpos=&;query="+base+ " " +collocate+" " +element.COLLOCATE_OF_PREP+"'target='_blank'>▶</a> </td>";
//  	moreobj.push({
//  	POS:"n",
// 	submenu:element.RELATION,
//     text: base+ " " +collocate+" " +element.COLLOCATE_OF_PREP,
//     url: 'https://skell.sketchengine.co.uk/run.cgi/concordance?lpos=&;query='+base+ " " +collocate+" " +element.COLLOCATE_OF_PREP,
//   	});
//  }
// else if(element.RELATION=="ADV V*")
// {

// 	additionaltext+="<tr class='moreoptions ADV V*'> <td id='test'  onClick=\"inserttext('"+collocate+ " " +base+"'); \" >"+collocate+ " " +base+"<td ><a href='https://skell.sketchengine.co.uk/run.cgi/wordsketch_concordance?headword="+base+ "-v;gramrel=modifiers%20of%20%w;coll=" +collocate+"-a'target='_blank'>▶</a> </td>";
// 	moreobj.push({
// 	submenu:element.RELATION,
//     text: collocate+ " " +base,
//     url: 'https://skell.sketchengine.co.uk/run.cgi/wordsketch_concordance?headword='+base+ "-v;gramrel=modifiers%20of%20%w;coll=" +collocate+"-a",
//   	});
// }
// else if(element.RELATION=="preposition"&& element.POS=="v")
// {
//  additionaltext+="<tr class='moreoptions'> <td id='test'  onClick=\"inserttext('"+base+ " " +collocate+" " +element.COLLOCATE_OF_PREP+"');  \" >"+base+ " " +collocate+" " +element.COLLOCATE_OF_PREP+"<td ><a href='https://skell.sketchengine.co.uk/run.cgi/concordance?lpos=&;query="+base+ " " +collocate+" " +element.COLLOCATE_OF_PREP+"'target='_blank'>▶</a> </td>";
// 	moreobj.push({
//  	POS:"v",
// 	submenu:element.RELATION,
//     text: base+ " " +collocate+" " +element.COLLOCATE_OF_PREP,
//     url: 'https://skell.sketchengine.co.uk/run.cgi/concordance?lpos=&;query='+base+ " " +collocate+" " +element.COLLOCATE_OF_PREP,
//   	});
// }
// else if(element.RELATION=="V* ADV")
// {
// 	additionaltext+="<tr class='moreoptions V* ADV'> <td id='test'  onClick=\"inserttext('"+base+ " " +collocate+"');  \" >"+base+ " " +collocate+"<td ><a href='https://skell.sketchengine.co.uk/run.cgi/wordsketch_concordance?headword="+base+ "-v;gramrel=modifiers%20of%20%w;coll=" +collocate+"-a'target='_blank'>▶</a> </td>";
// 	moreobj.push({
// 	submenu:element.RELATION,
//     text: base+ " " +collocate,
//     url: 'https://skell.sketchengine.co.uk/run.cgi/wordsketch_concordance?headword='+base+ "-v;gramrel=modifiers%20of%20%w;coll=" +skellurl(collocate)+"-a",
//   	});
// }
// else if(element.RELATION=="ADV ADJ*")
// {
// additionaltext+="<tr  class='moreoptions ADV ADJ*'> <td id='test' onClick=\"inserttext('"+collocate+ " " +base+"');  \" >"+collocate+ " " +base+"<td ><a href='https://skell.sketchengine.co.uk/run.cgi/wordsketch_concordance?headword="+base+ "-j;gramrel=modifiers%20of%20%w;coll=" +collocate+"-a'target='_blank'>▶</a> </td>";
// 	moreobj.push({
// 	submenu:element.RELATION,
//     text: collocate+ " " +base,
//     url: 'https://skell.sketchengine.co.uk/run.cgi/wordsketch_concordance?headword='+base+ "-j;gramrel=modifiers%20of%20%w;coll=" +collocate+"-a",
//   	});
// }
// else
// {
// additionaltext+="<tr class='moreoptions'> <td id='test'  onClick=\"inserttext('"+collocate+ " " +base+"');  \" >"+collocate+ " " +base+"<td ><a href='https://skell.sketchengine.co.uk/run.cgi/concordance?lpos=&;query="+collocate+ " " +base+"'target='_blank'>▶</a> </td>";
// 	moreobj.push({
// 	submenu:element.RELATION,
//     text: collocate+ " " +base,
//     url: 'https://skell.sketchengine.co.uk/run.cgi/concordance?lpos=&;query='+collocate+ " " +base,
//   	});
// }

/** SE API REFACTOR BEGIN */

if(element.RELATION=="subject_of")
{
additionaltext+="<tr class='moreoptions subject_of'> <td   onClick=\"inserttext('"+base+ " " +collocate+"'); \" >"+base+ " " +collocate+"<td ><a class='caret' href='https://skell.sketchengine.eu/#result?f=concordance&headword="+base+ "-n&gramrel=verbs%20with%20%25w%20as%20subject&coll=" +skellurl(collocate)+"-v&lang=en&query="+base+"'target='_blank'>▶</a> </td>";


moreobj.push({
	submenu:element.RELATION,
    text: base+ " " +collocate,
    url: 'https://skell.sketchengine.eu/#result?f=concordance&headword='+base+ '-n&gramrel=verbs%20with%20%25w%20as%20subject&coll=' +skellurl(collocate)+'-v&lang=en&query='+base,
  });
}
else if (element.RELATION=="object_of")
{
additionaltext+="<tr class='moreoptions object_of'> <td id='test'  onClick=\"inserttext('"+collocate+ " " +base+"'); \" >"+collocate+ " " +base+"<td ><a href='https://skell.sketchengine.eu/#result?f=concordance&headword="+base+ "-n&gramrel=verbs%20with%20%25w%20as%20object&coll=" +collocate+"-v&lang=en&query="+base+"'target='_blank'>▶</a> </td>";
moreobj.push({
	submenu:element.RELATION,
    text: collocate+ " " +base,
    url:'https://skell.sketchengine.eu/#result?f=concordance&headword='+ base+ "-n&gramrel=verbs%20with%20%25w%20as%20object&coll=" +collocate+"-v&lang=en&query="+base,
  });

}
 else if (element.RELATION=="modifier")
{
	additionaltext+="<tr class='moreoptions modifier'> <td id='test'  onClick=\"inserttext('"+collocate+ " " +base+"'); \" >"+collocate+ " " +base+"<td ><a href='https://skell.sketchengine.eu/#result?f=concordance&headword="+base+ "-n&gramrel=modifiers%20of%20%25w&coll=" +collocate+"-j&lang=en&query="+base+"'target='_blank'>▶</a> </td>";
 	moreobj.push({
	submenu:element.RELATION,
    text: collocate+ " " +base,
    url: 'https://skell.sketchengine.eu/#result?f=concordance&headword='+base+ "-n&gramrel=modifiers%20of%20%25w&coll=" +collocate+"-j&lang=en&query="+base,
  	});
 }
 else if(element.RELATION=="preposition"&& element.POS=="n")
 {
	 additionaltext+="<tr class='moreoptions'> <td id='test'  onClick=\"inserttext('"+base+ " " +collocate+" " +element.COLLOCATE_OF_PREP+"'); \" >"+base+ " " +collocate+" " +element.COLLOCATE_OF_PREP+"<td ><a href='https://skell.sketchengine.co.uk/run.cgi/concordance?lpos=&;query="+base+ " " +collocate+" " +element.COLLOCATE_OF_PREP+"'target='_blank'>▶</a> </td>";
 	moreobj.push({
 	POS:"n",
	submenu:element.RELATION,
    text: base+ " " +collocate+" " +element.COLLOCATE_OF_PREP,
    url: 'https://skell.sketchengine.co.uk/run.cgi/concordance?lpos=&;query='+base+ " " +collocate+" " +element.COLLOCATE_OF_PREP,
  	});
 }
else if(element.RELATION=="ADV V*")
{

	additionaltext+="<tr class='moreoptions ADV V*'> <td id='test'  onClick=\"inserttext('"+collocate+ " " +base+"'); \" >"+collocate+ " " +base+"<td ><a href='https://skell.sketchengine.eu/#result?f=concordance&headword="+base+ "-v&gramrel=modifiers%20of%20%25w&coll=" +collocate+"-a&lang=en&query="+base+"'target='_blank'>▶</a> </td>";
	moreobj.push({
	submenu:element.RELATION,
    text: collocate+ " " +base,
    url: 'https://skell.sketchengine.eu/#result?f=concordance&headword='+base+ "-v&gramrel=modifiers%20of%20%25w&coll=" +collocate+"-a&lang=en&query="+base,
  	});
}
else if(element.RELATION=="preposition"&& element.POS=="v")
{
 additionaltext+="<tr class='moreoptions'> <td id='test'  onClick=\"inserttext('"+base+ " " +collocate+" " +element.COLLOCATE_OF_PREP+"');  \" >"+base+ " " +collocate+" " +element.COLLOCATE_OF_PREP+"<td ><a href='https://skell.sketchengine.co.uk/run.cgi/concordance?lpos=&;query="+base+ " " +collocate+" " +element.COLLOCATE_OF_PREP+"'target='_blank'>▶</a> </td>";
	moreobj.push({
 	POS:"v",
	submenu:element.RELATION,
    text: base+ " " +collocate+" " +element.COLLOCATE_OF_PREP,
    url: 'https://skell.sketchengine.co.uk/run.cgi/concordance?lpos=&;query='+base+ " " +collocate+" " +element.COLLOCATE_OF_PREP,
  	});
}
else if(element.RELATION=="V* ADV")
{
	additionaltext+="<tr class='moreoptions V* ADV'> <td id='test'  onClick=\"inserttext('"+base+ " " +collocate+"');  \" >"+base+ " " +collocate+"<td ><a href='https://skell.sketchengine.eu/#result?f=concordance&headword="+base+ "-v&gramrel=modifiers%20of%20%25w&coll=" +collocate+"-a&lang=en&query="+base+"'target='_blank'>▶</a> </td>";
	moreobj.push({
	submenu:element.RELATION,
    text: base+ " " +collocate,
    url: 'https://skell.sketchengine.eu/#result?f=concordance&headword='+base+ "-v&gramrel=modifiers%20of%20%25w&coll=" +skellurl(collocate)+"-a&lang=en&query="+base,
  	});
}
else if(element.RELATION=="ADV ADJ*")
{
additionaltext+="<tr  class='moreoptions ADV ADJ*'> <td id='test' onClick=\"inserttext('"+collocate+ " " +base+"');  \" >"+collocate+ " " +base+"<td ><a href='https://skell.sketchengine.eu/#result?f=concordance&headword="+base+ "-j&gramrel=modifiers%20of%20%25w&coll=" +collocate+"-a&lang=en&query="+base+"'target='_blank'>▶</a> </td>";
	moreobj.push({
	submenu:element.RELATION,
    text: collocate+ " " +base,
    url: 'https://skell.sketchengine.eu/#result?f=concordance&headword='+base+ "-j&gramrel=modifiers%20of%20%25w&coll=" +collocate+"-a&lang=en&query="+base,
  	});
}
else
{
additionaltext+="<tr class='moreoptions'> <td id='test'  onClick=\"inserttext('"+collocate+ " " +base+"');  \" >"+collocate+ " " +base+"<td ><a href='https://skell.sketchengine.co.uk/run.cgi/concordance?lpos=&;query="+collocate+ " " +base+"'target='_blank'>▶</a> </td>";
	moreobj.push({
	submenu:element.RELATION,
    text: collocate+ " " +base,
    url: 'https://skell.sketchengine.co.uk/run.cgi/concordance?lpos=&;query='+collocate+ " " +base,
  	});
}

// .eu/#result?f=concordance&
// &lang=en&query=

/** SE API REFACTOR END */


//if(element.SENSE_DISAMBIGUATION)
//additionaltext+=" ("+element.SENSE_DISAMBIGUATION+")";
//if(element.LONGEST_COMMONEST_MATCH)
//additionaltext+="</td>	 <td id='test' onClick=\"inserttext('"+element.LONGEST_COMMONEST_MATCH+"'); \" >"+element.LONGEST_COMMONEST_MATCH;
//else
additionaltext+="</td>	";

if(element.EXAMPLE1){
//additionaltext+="</td>	<td> <span id='test' onClick=\"inserttext('"+element.EXAMPLE1+" ');  \" > 1) "+example1;
//if(element.EXAMPLE2)
//additionaltext+="</span></br> <span id='test' onClick=\"inserttext('"+element.EXAMPLE2+" '); \" > 2) "+example2;
//if(element.EXAMPLE3)
//additionaltext+="</span></br> <span id='test' onClick=\"inserttext('"+element.EXAMPLE3+" ');  \" > 3) "+example3;
}
else
//additionaltext+="</span></td>	<td> "+element.EXAMPLE1;
additionaltext+="</tr>"

//console.log(additionaltext);
//console.log(element.COLLOCATE);

});
additionaltext+="</table>"

document.getElementById("info").innerHTML = additionaltext;
additionaltext="";


//divScroll();

/*
document.getElementById("info").addEventListener("scroll",function(){
   var translate = "translate(0,"+this.scrollTop+"px)";
   this.querySelector("thead").style.transform = translate;
});*/

//myTable.scrollTop = myTable.scrollHeight;

//myTable.style.border="1px solid red";

function toggle(className, displayState){
   if(displayState=='block')
   {
		document.getElementsByClassName('morecoll')[0].style.display = displayState;
}
    var elements = document.getElementsByClassName(className)

    for (var i = 0; i < elements.length; i++){
   // console.log(elements[i]);
        elements[i].style.display = displayState;
    }
}

 // Shows
toggle('moreoptions', 'none');



var senses=selected_collocates.map(item => item.SENSE_DISAMBIGUATION+item.POS)
  .filter((value, index, self) => self.indexOf(value) === index); //create an array for polysemy
//console.log(senses);

var senses_filtered = senses.filter(function (el) {
switch (el)
{
 case "n":
 break;
 case "v":
 break;
 case "j":
 break;
 default:
 return el;
}

});//remove the null values from the polysemy array
var selected_senses=[];//empty array for adding polysemy values
var wordnoun="word <span> noun </span>";
wordnoun=wordnoun.replace(/&/g, "&amp;").replace(/>/g, "&gt;").replace(/</g, "&lt;").replace(/"/g, "&quot;");
//console.log(wordnoun);
//console.log(senses_filtered);
      // Create collocates
suggestions= [ word+" (noun)", word+" (verb)", word+" (adjective)"  ];//create the global menu for POS disambiguation
if(senses_filtered.length)//if Polysemy exists
{
//Create similar submenus for each polysemy value
  senses_filtered.forEach(function (element, index, array){
  selected_senses=[],senses_menun=[];
  senses_menuv=[]; //empty the polysemy menu and values to avoid duplication
  subject_of=[], object_of=[],modifier=[],preposition=[], advv=[],prep=[],vadv=[], advadj=[],prepad=[];//empty submenus and data to avoid duplication
  //collocate_menu1=[];
    //collocate_menu2=[];
selected_senses=selected_collocates.filter(function(item){
return item.SENSE_DISAMBIGUATION==senses_filtered[index].slice(0,-1);
});//Filter collocations for the current polysemy value

selected_senses=selected_senses.concat(selected_collocates.filter(function(item){
return item.SENSE_DISAMBIGUATION=="";
}));//add the remaining collocations to the current polysemy values as each polysemy menu has additional prepositional values
selected_senses.forEach(function (element, index, array)
 {element.COLLOCATE=element.COLLOCATE.toString().toLowerCase();
    if(element.Base==lemma)
  {
   //if(element.SENSE_DISAMBIGUATION)
     {
    if(lemmatisation)
        {if(lemmaPOS.indexOf(element.POS)>=0)
 {

     //console.log(element.POS);

  example_menu=[];
  longest_match_menu=[];
  //element.EXAMPLE1= element.EXAMPLE1.replace(element.Base, element.Base.toUpperCase());
  examples=[element.EXAMPLE1,element.EXAMPLE2,element.EXAMPLE3];
  element.EXAMPLES=examples;
  longest_matches={}

  element.EXAMPLES.forEach(function (element1, index, array)
 { // var text=element1.replace(element.Base, element.Base.toUpperCase());
 //text=text.replace(element.COLLOCATE, element.COLLOCATE.toUpperCase());

 var example=convertto(element1,element.COLLOCATE,element.COLLOCATESTEM,1);
example =convertto(example,element.Base,element.BASESTEM,1);
 example_menu.push({
    text: example,
    inserttext:element1.toLowerCase(),
     onPostRender: function () {
      var text = this.getEl('text');
      text.innerHTML = example;
    },
    onclick:function(){

            editor.insertContent(editor.dom.encode(element1.toLowerCase()));
            editor.insertContent(editor.dom.encode(" "));

            clearmenu();
             //startSpellchecking();


      }
  });
 });
 example_menu.push({ text: '-' });

/*  example_menu.push({
    text: (editor.plugins.fullscreen.isFullscreen())?"Show more collocations":"Hide more collocations",
    onclick:function(){

                   //if(editor.plugins.fullscreen.isFullscreen())
        editor.execCommand('mceFullScreen');

      }
  });*/
//example_menu.push({ text: '-' });

  example_menu.push({
    text: "** Please take care to adapt examples to your own text **",
  });
  longest_match_menu.push({
    text: element.LONGEST_COMMONEST_MATCH,
    menu:example_menu,
    onclick:function(){ clicks++;
     if (timer) clearTimeout(timer);
   timer = setTimeout(function() { //console.log('Single');
   clicks=0;}, 250);
      if(clicks==2)
          {
          //console.log(editor.dom.encode(element));
        editor.insertContent(editor.dom.encode(element.LONGEST_COMMONEST_MATCH));
        editor.insertContent(editor.dom.encode(" "));

        clicks=0;
        clearmenu();
         }
      }
  });

  example_menu.push({ text: '-' });
  /*example_menu.push({
    text: 'www.externalresource.com',
    onclick:function(){

            //editor.insertContent(editor.dom.encode(element));
            //clearmenu();
             //startSpellchecking();
             window.open('../');

      }
  });*/

 //element.EXAMPLEMENU=example_menu;
 element.LONGESTMENU= longest_match_menu;
 collocate_obj.push(element);
  collocate_menu_global[element.RELATION]={};

 if(element.EXAMPLE1){

 /* if(!flag[element.POS+element.RELATION])
    {
   flag[element.POS+element.RELATION]=element.Base+ " " +element.COLLOCATE;

    }
 */

 if(element.RELATION=="subject_of"&& element.POS=="n")
 {

 if(!flag[element.POS+element.RELATION])
    {
   flag[element.POS+element.RELATION]=element.Base+ " " +element.COLLOCATE;

    }


 collocate[index]=element.Base+ " " +element.COLLOCATE;
 subject_of.push({
    text: element.LONGEST_COMMONEST_MATCH,
    menu:example_menu,
    onclick:function(){ clicks++;
     if (timer) clearTimeout(timer);
   timer = setTimeout(function() { //console.log('Single');
   clicks=0;}, 250);
      if(clicks==2)
          {
          //console.log(editor.dom.encode(element));
        editor.insertContent(editor.dom.encode(element.LONGEST_COMMONEST_MATCH));
        editor.insertContent(editor.dom.encode(" "));

        clicks=0;
        clearmenu();
         }
      }
  });
  }
  else if (element.RELATION=="object_of"&& element.POS=="n")
  {
 collocate[index]= element.COLLOCATE+ " " +element.Base;

  if(!flag[element.POS+element.RELATION])
    {
   flag[element.POS+element.RELATION]=element.COLLOCATE+" "+element.Base ;

    }



 object_of.push({
    text: element.LONGEST_COMMONEST_MATCH,
    menu:example_menu,
    onclick:function(){ clicks++;
     if (timer) clearTimeout(timer);
   timer = setTimeout(function() { //console.log('Single');
   clicks=0;}, 250);
      if(clicks==2)
          {
          //console.log(editor.dom.encode(element));
        editor.insertContent(editor.dom.encode(element.LONGEST_COMMONEST_MATCH));
        editor.insertContent(editor.dom.encode(" "));

        clicks=0;
        clearmenu();
         }
      }
  });
  }
  else if (element.RELATION=="modifier"&& element.POS=="n")
  {
 collocate[index]= element.COLLOCATE+ " " +element.Base;

  if(!flag[element.POS+element.RELATION])
    {
   flag[element.POS+element.RELATION]=element.COLLOCATE+" "+element.Base ;

    }

 modifier.push({
    text: element.COLLOCATE+ " " +element.Base,
    menu:example_menu,
    onclick:function(){ clicks++;
     if (timer) clearTimeout(timer);
   timer = setTimeout(function() { //console.log('Single');
   clicks=0;}, 250);
      if(clicks==2)
          {
          //console.log(editor.dom.encode(element));
        editor.insertContent(editor.dom.encode(element.COLLOCATE+ " " +element.Base));
        editor.insertContent(editor.dom.encode(" "));

        clicks=0;
        clearmenu();
         }
      }
  });
  }
  else if(element.RELATION=="preposition"&& element.POS=="n")
  {
  collocate[index]=element.COLLOCATE_OF_PREP;

   if(!flag[element.POS+element.RELATION])
    {
   flag[element.POS+element.RELATION]=element.Base+ " " +element.COLLOCATE+" " +element.COLLOCATE_OF_PREP ;

    }

  preposition.push({
    text: element.Base+ " " +element.COLLOCATE+" " +element.COLLOCATE_OF_PREP,
    menu:example_menu,
    basecollocate:element.Base+ " " +element.COLLOCATE,
    preposition:element.COLLOCATE_OF_PREP,
    onclick:function(){ clicks++;
     if (timer) clearTimeout(timer);
   timer = setTimeout(function() { //console.log('Single');
   clicks=0;}, 250);
      if(clicks==2)
          {
          //console.log(editor.dom.encode(element));
        editor.insertContent(editor.dom.encode(element.Base+ " " +element.COLLOCATE));
        editor.insertContent(editor.dom.encode(" "));
        clicks=0;
        clearmenu();
         }
      }
  });
  }
   else if(element.RELATION=="ADV V*"&& element.POS=="v")
  {
  collocate[index]=element.COLLOCATE_OF_PREP;
  if(!flag[element.POS+element.RELATION])
    {
   flag[element.POS+element.RELATION]=element.COLLOCATE+ " " +element.Base;

    }
  advv.push({
   	text: (element.LONGEST_COMMONEST_MATCH.length) ? 	element.LONGEST_COMMONEST_MATCH: element.COLLOCATE+ " " +element.Base,
    menu:example_menu,
    onclick:function(){ clicks++;
     if (timer) clearTimeout(timer);
   timer = setTimeout(function() { //console.log('Single');
   clicks=0;}, 250);
      if(clicks==2)
          {
          //console.log(editor.dom.encode(element));
        editor.insertContent(editor.dom.encode((element.LONGEST_COMMONEST_MATCH.length) ? 	element.LONGEST_COMMONEST_MATCH: element.COLLOCATE+ " " +element.Base));
        editor.insertContent(editor.dom.encode(" "));
        clicks=0;
        clearmenu();
         }
      }
  });
  }
  else if(element.RELATION=="preposition"&& element.POS=="v")
  {
  collocate[index]=element.COLLOCATE_OF_PREP;
  if(!flag[element.POS+element.RELATION])
    {
   flag[element.POS+element.RELATION]=element.Base+ " " +element.COLLOCATE+" " +element.COLLOCATE_OF_PREP ;

    }

  prep.push({
    text: element.Base+ " " +element.COLLOCATE+" " +element.COLLOCATE_OF_PREP,
    menu:example_menu,
    onclick:function(){ clicks++;
     if (timer) clearTimeout(timer);
   timer = setTimeout(function() { //console.log('Single');
   clicks=0;}, 250);
      if(clicks==2)
          {
          //console.log(editor.dom.encode(element));
        editor.insertContent(editor.dom.encode(element.Base+ " " +element.COLLOCATE));
        editor.insertContent(editor.dom.encode(" "));
        clicks=0;
        clearmenu();
         }
      }
  });
  }
  else if(element.RELATION=="V* ADV"&& element.POS=="v")
  {
  collocate[index]=element.COLLOCATE_OF_PREP;
	console.log(flag[element.POS+element.RELATION]);

  if(!flag[element.POS+element.RELATION])
    {
   flag[element.POS+element.RELATION]=element.Base+ " " +element.COLLOCATE;

    }
  vadv.push({
    text: element.Base+ " " +element.COLLOCATE,
    menu:example_menu,
    onclick:function(){ clicks++;
     if (timer) clearTimeout(timer);
   timer = setTimeout(function() { //console.log('Single');
   clicks=0;}, 250);
      if(clicks==2)
          {
          //console.log(editor.dom.encode(element));
        editor.insertContent(editor.dom.encode(element.Base+ " " +element.COLLOCATE));
        editor.insertContent(editor.dom.encode(" "));
        clicks=0;
        clearmenu();
         }
      }
  });
  }
  else if(element.RELATION=="ADV ADJ*")
  {
  collocate[index]=element.COLLOCATE_OF_PREP;

  if(!flag[element.POS+element.RELATION])
    {
   flag[element.POS+element.RELATION]=element.COLLOCATE+ " " +element.Base;

    }

  advadj.push({
    text: element.COLLOCATE+ " " +element.Base,
    menu:example_menu,
    onclick:function(){ clicks++;
     if (timer) clearTimeout(timer);
   timer = setTimeout(function() { //console.log('Single');
   clicks=0;}, 250);
      if(clicks==2)
          {
          //console.log(editor.dom.encode(element));
        editor.insertContent(editor.dom.encode(element.COLLOCATE+ " " +element.Base));
        editor.insertContent(editor.dom.encode(" "));
        clicks=0;
        clearmenu();
         }
      }
  });
  }
  else if(element.RELATION=="preposition"&& element.POS=="j")
  {
  collocate[index]=element.COLLOCATE_OF_PREP;
  if(!flag[element.POS+element.RELATION])
    {
   flag[element.POS+element.RELATION]=element.Base+ " " +element.COLLOCATE+" " +element.COLLOCATE_OF_PREP ;

    }

  prepad.push({
    text: element.Base+ " " +element.COLLOCATE+" " +element.COLLOCATE_OF_PREP,
    menu:example_menu,
    onclick:function(){ clicks++;
     if (timer) clearTimeout(timer);
   timer = setTimeout(function() { //console.log('Single');
   clicks=0;}, 250);
      if(clicks==2)
          {
          //console.log(editor.dom.encode(element));
        editor.insertContent(editor.dom.encode(element.Base+ " " +element.COLLOCATE));
        editor.insertContent(editor.dom.encode(" "));
        clicks=0;
        clearmenu();
         }
      }
  });
  }
  else
  {
  collocate[index]=element.COLLOCATE+ " "+element.Base;
  }}

  //pos[index]=element.POS;
  //relations[index]=element.RELATION;
  //longest_matches[index]=element.LONGEST_COMMONEST_MATCH;

 }}
    else
      {

     //console.log(element.POS);

  example_menu=[];
  longest_match_menu=[];
  examples=[element.EXAMPLE1,element.EXAMPLE2,element.EXAMPLE3];
  element.EXAMPLES=examples;
  longest_matches={}

  element.EXAMPLES.forEach(function (element1, index, array)
 {  //var text=element1.replace(element.Base, element.Base.toUpperCase());
// text=text.replace(element.COLLOCATE, element.COLLOCATE.toUpperCase());
var example=convertto(element1,element.COLLOCATE,element.COLLOCATESTEM,1);
example =convertto(example,element.Base,element.BASESTEM,1);
 example_menu.push({
    text: example,
    inserttext:element1.toLowerCase(),
    onPostRender: function () {
      var text = this.getEl('text');
      text.innerHTML = example;
    },
    onclick:function(){

            editor.insertContent(editor.dom.encode(element1.toLowerCase()));
            editor.insertContent(editor.dom.encode(" "));

            clearmenu();
             //startSpellchecking();


      }
  });
 });

 example_menu.push({ text: '-' });

 /* example_menu.push({
    text: (editor.plugins.fullscreen.isFullscreen())?"Show more collocations":"Hide more collocations",
    onclick:function(){

                  // if(editor.plugins.fullscreen.isFullscreen())
        editor.execCommand('mceFullScreen');

      }
  });
 example_menu.push({ text: '-' });*/
  example_menu.push({
    text: "** Please take care to adapt examples to your own text **",
  });

  longest_match_menu.push({
    text: element.LONGEST_COMMONEST_MATCH,
    menu:example_menu,
    onclick:function(){ clicks++;
     if (timer) clearTimeout(timer);
   timer = setTimeout(function() { //console.log('Single');
   clicks=0;}, 250);
      if(clicks==2)
          {
          //console.log(editor.dom.encode(element));
        editor.insertContent(editor.dom.encode(element.LONGEST_COMMONEST_MATCH));
        editor.insertContent(editor.dom.encode(" "));

        clicks=0;
        clearmenu();
         }
      }
  });

  example_menu.push({ text: '-' });
  /*example_menu.push({
    text: 'www.externalresource.com',
    onclick:function(){

            //editor.insertContent(editor.dom.encode(element));
            //clearmenu();
             //startSpellchecking();
             window.open('../');

      }
  });*/

 //element.EXAMPLEMENU=example_menu;
 element.LONGESTMENU= longest_match_menu;
 collocate_obj.push(element);
  collocate_menu_global[element.RELATION]={};

 if(element.EXAMPLE1){

 /* if(!flag[element.POS+element.RELATION])
    {
   flag[element.POS+element.RELATION]=element.Base+ " " +element.COLLOCATE;

    }
 */

 if(element.RELATION=="subject_of"&& element.POS=="n")
 {

 if(!flag[element.POS+element.RELATION])
    {
   flag[element.POS+element.RELATION]=element.Base+ " " +element.COLLOCATE;

    }


 collocate[index]=element.Base+ " " +element.COLLOCATE;
 subject_of.push({
    text: element.LONGEST_COMMONEST_MATCH,
    menu:example_menu,
    onclick:function(){ clicks++;
     if (timer) clearTimeout(timer);
   timer = setTimeout(function() { //console.log('Single');
   clicks=0;}, 250);
      if(clicks==2)
          {
          //console.log(editor.dom.encode(element));
        editor.insertContent(editor.dom.encode(element.LONGEST_COMMONEST_MATCH));
        editor.insertContent(editor.dom.encode(" "));
        clicks=0;
        clearmenu();
         }
      }
  });
  }
  else if (element.RELATION=="object_of"&& element.POS=="n")
  {
 collocate[index]= element.COLLOCATE+ " " +element.Base;

  if(!flag[element.POS+element.RELATION])
    {
   flag[element.POS+element.RELATION]=element.COLLOCATE+" "+element.Base ;

    }



 object_of.push({
    text: element.LONGEST_COMMONEST_MATCH,
    menu:example_menu,
    onclick:function(){ clicks++;
     if (timer) clearTimeout(timer);
   timer = setTimeout(function() { //console.log('Single');
   clicks=0;}, 250);
      if(clicks==2)
          {
          //console.log(editor.dom.encode(element));
        editor.insertContent(editor.dom.encode(element.LONGEST_COMMONEST_MATCH));
        editor.insertContent(editor.dom.encode(" "));
        clicks=0;
        clearmenu();
         }
      }
  });
  }
  else if (element.RELATION=="modifier"&& element.POS=="n")
  {
 collocate[index]= element.COLLOCATE+ " " +element.Base;

  if(!flag[element.POS+element.RELATION])
    {
   flag[element.POS+element.RELATION]=element.COLLOCATE+" "+element.Base ;

    }

 modifier.push({
    text: element.COLLOCATE+ " " +element.Base,
    menu:example_menu,
    onclick:function(){ clicks++;
     if (timer) clearTimeout(timer);
   timer = setTimeout(function() { //console.log('Single');
   clicks=0;}, 250);
      if(clicks==2)
          {
          //console.log(editor.dom.encode(element));
        editor.insertContent(editor.dom.encode(element.COLLOCATE+ " " +element.Base));
        editor.insertContent(editor.dom.encode(" "));
        clicks=0;
        clearmenu();
         }
      }
  });
  }
  else if(element.RELATION=="preposition"&& element.POS=="n")
  {
  collocate[index]=element.COLLOCATE_OF_PREP;

   if(!flag[element.POS+element.RELATION])
    {
   flag[element.POS+element.RELATION]=element.Base+ " " +element.COLLOCATE+" " +element.COLLOCATE_OF_PREP ;

    }

  preposition.push({
    text: element.Base+ " " +element.COLLOCATE+" " +element.COLLOCATE_OF_PREP,
    menu:example_menu,
    basecollocate:element.Base+ " " +element.COLLOCATE,
    preposition:element.COLLOCATE_OF_PREP,
    onclick:function(){ clicks++;
     if (timer) clearTimeout(timer);
   timer = setTimeout(function() { //console.log('Single');
   clicks=0;}, 250);
      if(clicks==2)
          {
          //console.log(editor.dom.encode(element));
        editor.insertContent(editor.dom.encode(element.Base+ " " +element.COLLOCATE));
        editor.insertContent(editor.dom.encode(" "));
        clicks=0;
        clearmenu();
         }
      }
  });
  }
   else if(element.RELATION=="ADV V*"&& element.POS=="v")
  {
  collocate[index]=element.COLLOCATE_OF_PREP;
  if(!flag[element.POS+element.RELATION])
    {
   flag[element.POS+element.RELATION]=element.COLLOCATE+ " " +element.Base;

    }
  advv.push({
    //text: element.COLLOCATE+ " " +element.Base,
   	text: (element.LONGEST_COMMONEST_MATCH.length) ? 	element.LONGEST_COMMONEST_MATCH: element.COLLOCATE+ " " +element.Base,
    menu:example_menu,
    onclick:function(){ clicks++;
     if (timer) clearTimeout(timer);
   timer = setTimeout(function() { //console.log('Single');
   clicks=0;}, 250);
      if(clicks==2)
          {
          //console.log(editor.dom.encode(element));
        editor.insertContent(editor.dom.encode((element.LONGEST_COMMONEST_MATCH.length) ? 	element.LONGEST_COMMONEST_MATCH: element.COLLOCATE+ " " +element.Base));
        editor.insertContent(editor.dom.encode(" "));
        clicks=0;
        clearmenu();
         }
      }
  });
  }
  else if(element.RELATION=="preposition"&& element.POS=="v")
  {
  collocate[index]=element.COLLOCATE_OF_PREP;
  if(!flag[element.POS+element.RELATION])
    {
   flag[element.POS+element.RELATION]=element.Base+ " " +element.COLLOCATE+" " +element.COLLOCATE_OF_PREP ;

    }

  prep.push({
    text: element.Base+ " " +element.COLLOCATE+" " +element.COLLOCATE_OF_PREP,
    menu:example_menu,
    onclick:function(){ clicks++;
     if (timer) clearTimeout(timer);
   timer = setTimeout(function() { //console.log('Single');
   clicks=0;}, 250);
      if(clicks==2)
          {
          //console.log(editor.dom.encode(element));
        editor.insertContent(editor.dom.encode(element.Base+ " " +element.COLLOCATE));
        editor.insertContent(editor.dom.encode(" "));
        clicks=0;
        clearmenu();
         }
      }
  });
  }
  else if(element.RELATION=="V* ADV"&& element.POS=="v")
  {
  collocate[index]=element.COLLOCATE_OF_PREP;
	console.log(flag[element.POS+element.RELATION]);

  if(!flag[element.POS+element.RELATION])
    {
   flag[element.POS+element.RELATION]=element.Base+ " " +element.COLLOCATE;

    }
  vadv.push({
    text: element.Base+ " " +element.COLLOCATE,
    menu:example_menu,
    onclick:function(){ clicks++;
     if (timer) clearTimeout(timer);
   timer = setTimeout(function() { //console.log('Single');
   clicks=0;}, 250);
      if(clicks==2)
          {
          //console.log(editor.dom.encode(element));
        editor.insertContent(editor.dom.encode(element.Base+ " " +element.COLLOCATE));
        editor.insertContent(editor.dom.encode(" "));
        clicks=0;
        clearmenu();
         }
      }
  });
  }
  else if(element.RELATION=="ADV ADJ*")
  {
  collocate[index]=element.COLLOCATE_OF_PREP;

  if(!flag[element.POS+element.RELATION])
    {
   flag[element.POS+element.RELATION]=element.COLLOCATE+ " " +element.Base;

    }

  advadj.push({
    text: element.COLLOCATE+ " " +element.Base,
    menu:example_menu,
    onclick:function(){ clicks++;
     if (timer) clearTimeout(timer);
   timer = setTimeout(function() { //console.log('Single');
   clicks=0;}, 250);
      if(clicks==2)
          {
          //console.log(editor.dom.encode(element));
        editor.insertContent(editor.dom.encode(element.COLLOCATE+ " " +element.Base));
        editor.insertContent(editor.dom.encode(" "));
        clicks=0;
        clearmenu();
         }
      }
  });
  }
  else if(element.RELATION=="preposition"&& element.POS=="j")
  {
  collocate[index]=element.COLLOCATE_OF_PREP;
  if(!flag[element.POS+element.RELATION])
    {
   flag[element.POS+element.RELATION]=element.Base+ " " +element.COLLOCATE+" " +element.COLLOCATE_OF_PREP ;

    }

  prepad.push({
    text: element.Base+ " " +element.COLLOCATE+" " +element.COLLOCATE_OF_PREP,
    menu:example_menu,
    onclick:function(){ clicks++;
     if (timer) clearTimeout(timer);
   timer = setTimeout(function() { //console.log('Single');
   clicks=0;}, 250);
      if(clicks==2)
          {
          //console.log(editor.dom.encode(element));
        editor.insertContent(editor.dom.encode(element.Base+ " " +element.COLLOCATE));
        editor.insertContent(editor.dom.encode(" "));
        clicks=0;
        clearmenu();
         }
      }
  });
  }
  else
  {
  collocate[index]=element.COLLOCATE+ " "+element.Base;
  }}

  //pos[index]=element.POS;
  //relations[index]=element.RELATION;
  //longest_matches[index]=element.LONGEST_COMMONEST_MATCH;

 }
   }
  }
 });

if(subject_of.length && senses_filtered[index].slice(-1)=="n")
{
//console.log(subject_of[0].text);
var submenu=subject_of[0].text;
if(subject_of.length>=8){
subject_of.push({ text: '-' });
subject_of.push({
    text: "More",
    onclick:function(){toggle('subject_of', 'block');
    if(editor.plugins.fullscreen.isFullscreen())
        editor.execCommand('mceFullScreen');
}
  });}
 senses_menun.push({
    text: submenu,
    menu: subject_of,
    relation:"+V",
    onPostRender: function () {
      var text = this.getEl('text');
      text.innerHTML = submenu+"<span style=\"float:right;padding-right:20px;\">+V</span>";
    },
    ondblclick:function(){
            editor.insertContent(editor.dom.encode(submenu));
            editor.insertContent(editor.dom.encode(" "));
            clearmenu();
      }
  });
 }
 else if(subject_of.length)
{collocate_menu=[];
console.log(subject_of.length);
if(subject_of.length>=8)
{
subject_of.push({ text: '-' });
subject_of.push({
    text: "More",
    onclick:function(){console.log(this);toggle('subject_of', 'block');
    if(editor.plugins.fullscreen.isFullscreen())
        editor.execCommand('mceFullScreen');

}
  });}
 collocate_menu.push({
    text: flag['nsubject_of'],
    menu: subject_of,
    relation:"+V",
    onPostRender: function () {
      var text = this.getEl('text');
      text.innerHTML = flag['nsubject_of']+"<span style=\"float:right;padding-right:20px;\">+V</span>";
    },
    ondblclick:function(){
            editor.insertContent(editor.dom.encode(flag['nsubject_of']));
            editor.insertContent(editor.dom.encode(" "));
            clearmenu();
      }
  });
 }

if(object_of.length && senses_filtered[index].slice(-1)=="n")
{
console.log(object_of[0].text);
var objmenu=object_of[0].text;
if(object_of.length>=8){
object_of.push({ text: '-' });
object_of.push({
    text: "More",
    onclick:function(){toggle('object_of', 'block');
    if(editor.plugins.fullscreen.isFullscreen())
        editor.execCommand('mceFullScreen');
}
  });
  }
 senses_menun.push({
    text: objmenu,
    menu: object_of,
    relation:"V+",
    onPostRender: function () {
      var text = this.getEl('text');
      text.innerHTML = objmenu+"<span style=\"float:right;padding-right:20px;\">V+</span>";
    },
    ondblclick:function(){
            editor.insertContent(editor.dom.encode(objmenu));
            editor.insertContent(editor.dom.encode(" "));
            clearmenu();
      }
  });
 }
 else if (object_of.length)
 {
 console.log(object_of.length);
if(object_of.length>=8){
object_of.push({ text: '-' });

object_of.push({
    text: "More",
    onclick:function(){console.log(this);toggle('object_of', 'block');
    if(editor.plugins.fullscreen.isFullscreen())
        editor.execCommand('mceFullScreen');
}
  });}
   collocate_menu.push({
    text: flag['nobject_of'],
    menu: object_of,
     relation:"V+",
     onPostRender: function () {
      var text = this.getEl('text');
      text.innerHTML = flag['nobject_of']+"<span style=\"float:right;padding-right:20px;\">V+</span>";
    },
    ondblclick:function(){
            editor.insertContent(editor.dom.encode(flag['nobject_of']));
            editor.insertContent(editor.dom.encode(" "));
            clearmenu();
      }
  });
  }
 if(modifier.length && senses_filtered[index].slice(-1)=="n")
{
console.log(modifier[0].text);
var modmenu=modifier[0].text;
if(modifier.length>=8)
{   modifier.push({ text: '-' });

modifier.push({
    text: "More",
    onclick:function(){toggle('modifier', 'block');
    if(editor.plugins.fullscreen.isFullscreen())
        editor.execCommand('mceFullScreen');
}
  });}
 senses_menun.push({
    text: modmenu,
    menu: modifier,
    relation:"Adj+",
    onPostRender: function () {
      var text = this.getEl('text');
      text.innerHTML = modmenu+"<span style=\"float:right;padding-right:20px;\">Adj+</span>";
    },
    ondblclick:function(){
            editor.insertContent(editor.dom.encode(modmenu));
            editor.insertContent(editor.dom.encode(" "));
            clearmenu();
      }
  });
 }
 else if(modifier.length)
  {
  console.log(modifier.length);
if(modifier.length>=8){
    modifier.push({ text: '-' });

modifier.push({
    text: "More",
    onclick:function(){console.log(this);toggle('modifier', 'block');
    if(editor.plugins.fullscreen.isFullscreen())
        editor.execCommand('mceFullScreen');
}
  });}
   collocate_menu.push({
    text: flag['nmodifier'],
    menu: modifier,
    relation:"Adj+",
     onPostRender: function () {
      var text = this.getEl('text');
      text.innerHTML = flag['nmodifier']+"<span style=\"float:right;padding-right:20px;\">Adj+</span>";
    },
    ondblclick:function(){
            editor.insertContent(editor.dom.encode(flag['nmodifier']));
            editor.insertContent(editor.dom.encode(" "));
            clearmenu();
      }
  });
  }
  if(preposition.length && senses_filtered[index].slice(-1)=="n")
 {
 preposition.forEach(function (element, index, array)
 {senses_menun.push(element); });

 }
   else if(preposition.length)
 {
 preposition.forEach(function (element, index, array)
 {collocate_menu.push(element); });

 }
/*
 if(preposition.length)
   collocate_menu.push({
    text: flag['npreposition'],
    menu: preposition,
    ondblclick:function(){
            editor.insertContent(editor.dom.encode(flag['npreposition']));
            clearmenu();
      }
  });
 Show prepositions one step earlier
 */
 console.log(senses_filtered[index]);
 if(senses_menun.length)
   collocate_menu.push({
    text:lemma+" ("+senses_filtered[index].slice(0,-1) +")",
    lemma:lemma,
    sense:senses_filtered[index].slice(0,-1),
    menu: senses_menun,

  });



  if(advv.length && senses_filtered[index].slice(-1)=="v")
{
console.log(advv[0].text);
var advmenu=advv[0].text;
if(advv.length>=8){
advv.push({ text: '-' });
advv.push({
    text: "More",
    onclick:function(){console.log(this);toggle('advv', 'block');
    if(editor.plugins.fullscreen.isFullscreen())
        editor.execCommand('mceFullScreen');
}
  });}
 senses_menuv.push({
    text: advmenu,
    menu: advv,
    relation:"Adv+",
    onPostRender: function () {
      var text = this.getEl('text');
      text.innerHTML = advmenu+"<span style=\"float:right;padding-right:20px;\">Adv+</span>";
    },
    ondblclick:function(){
            editor.insertContent(editor.dom.encode(advmenu));
            editor.insertContent(editor.dom.encode(" "));
            clearmenu();
      }
  });
 }
 else if(advv.length)
  {collocate_menu1=[];
  console.log(advv.length);
if(advv.length==8)
{    advv.push({ text: '-' });

advv.push({
    text: "More",
    onclick:function(){console.log(this);toggle('advv', 'block');
    if(editor.plugins.fullscreen.isFullscreen())
        editor.execCommand('mceFullScreen');
}
  });
  }
   collocate_menu1.push({
    text: flag["vADV V*"],
    menu: advv,
    relation:"Adv+",
     onPostRender: function () {
      var text = this.getEl('text');
      text.innerHTML = flag['vADV V*']+"<span style=\"float:right;padding-right:20px;\">Adv+</span>";
    },
    ondblclick:function(){
            editor.insertContent(editor.dom.encode(flag["vADV V*"]));
            editor.insertContent(editor.dom.encode(" "));
            clearmenu();
      }
  });
  }

  if(vadv.length && senses_filtered[index].slice(-1)=="v")
{
//console.log(vadv[0].text);
var vadvmenu=vadv[0].text;
if(vadv.length>=8){
vadv.push({ text: '-' });
vadv.push({
    text: "More",
    onclick:function(){console.log(this);toggle('vadv', 'block');
    if(editor.plugins.fullscreen.isFullscreen())
        editor.execCommand('mceFullScreen');
}
  });}
 senses_menuv.push({
    text: vadvmenu,
    menu: vadv,
	relation:"+Adv",
    onPostRender: function () {
      var text = this.getEl('text');
      text.innerHTML = vadvmenu+"<span style=\"float:right;padding-right:20px;\">+Adv</span>";
    },
    ondblclick:function(){
            editor.insertContent(editor.dom.encode(vadvmenu));
            editor.insertContent(editor.dom.encode(" "));
            clearmenu();
      }
  });
 }
   else if(vadv.length)
  {collocate_menu1=[];
  console.log(vadv.length);
if(vadv.length==8)
{    vadv.push({ text: '-' });

vadv.push({
    text: "More",
    onclick:function(){console.log(this);toggle('vadv', 'block');
    if(editor.plugins.fullscreen.isFullscreen())
        editor.execCommand('mceFullScreen');
}
  });
  }
   collocate_menu1.push({
    text: flag["vV* ADV"],
    menu: advv,
    relation:"Adv+",
     onPostRender: function () {
      var text = this.getEl('text');
      text.innerHTML = flag['vV* ADV']+"<span style=\"float:right;padding-right:20px;\">Adv+</span>";
    },
    ondblclick:function(){
            editor.insertContent(editor.dom.encode(flag["vV* ADV"]));
            editor.insertContent(editor.dom.encode(" "));
            clearmenu();
      }
  });
  }
  if(prep.length && senses_filtered[index].slice(-1)=="v")
  {
 prep.forEach(function (element, index, array)
 {senses_menuv.push(element); });

 }
  else if(prep.length)
  {
 prep.forEach(function (element, index, array)
 {collocate_menu1.push(element); });

 }
      console.log(senses_filtered[index]);

  if(senses_menuv.length)
   collocate_menu1.push({
    text:lemma+" ("+senses_filtered[index].slice(0,-1) +")",
    lemma:lemma,
    sense:senses_filtered[index].slice(0,-1),
    menu: senses_menuv,

  });
        console.log(senses_menuv);


});
  //console.log(collocate_menu);

 if(collocate_menu.length){
 collocate_menu.push({ text: '-' });
 // collocate_menu.push({ text: 'Hide' });
  }





/*  if(prep.length)
  collocate_menu1.push({
    text: flag["vpreposition"],
    menu: prep,
    ondblclick:function(){
            editor.insertContent(editor.dom.encode(flag["vpreposition"]));
            clearmenu();
      }
  });

  */



   /*

  if(advv.length)
   collocate_menu1.push({
    text: flag["vADV V*"],
    menu: advv,
     onPostRender: function () {
      var text = this.getEl('text');
      text.innerHTML = flag['vADV V*']+"<span style=\"float:right;padding-right:20px;\">Adv+</span>";
    },
    ondblclick:function(){
            editor.insertContent(editor.dom.encode(flag["vADV V*"]));
            editor.insertContent(editor.dom.encode(" "));
            clearmenu();
      }
  });

  if(vadv.length)
   collocate_menu1.push({
    text: flag["vV* ADV"],
    menu: vadv,
     onPostRender: function () {
      var text = this.getEl('text');
      text.innerHTML = flag['vV* ADV']+"<span style=\"float:right;padding-right:20px;\">+Adv</span>";
    },
    ondblclick:function(){
            editor.insertContent(editor.dom.encode(flag["vV* ADV"]));
            editor.insertContent(editor.dom.encode(" "));
            clearmenu();
      }
  });

if(prep.length)
  collocate_menu1.push({
    text: flag["vpreposition"],
    menu: prep,
    ondblclick:function(){
            editor.insertContent(editor.dom.encode(flag["vpreposition"]));
            clearmenu();
      }
  });


 if(prep.length)
  {
 prep.forEach(function (element, index, array)
 {collocate_menu1.push(element); });

 } */


if(collocate_menu1.length){
  collocate_menu1.push({ text: '-' });
 // collocate_menu1.push({ text: 'Hide' });
  }

   if(advadj.length){
   collocate_menu2=[];
   console.log(advadj.length);
if(advadj.length==8){
    advadj.push({ text: '-' });

advadj.push({
    text: "More",
    onclick:function(){console.log(this);toggle('ADV ADJ*', 'block');
    if(editor.plugins.fullscreen.isFullscreen())
        editor.execCommand('mceFullScreen');
}
  });}
  collocate_menu2.push({
    text: flag["jADV ADJ*"],
    menu: advadj,
    relation:"Adv+",
     onPostRender: function () {
      var text = this.getEl('text');
      text.innerHTML = flag['jADV ADJ*']+"<span style=\"float:right;padding-right:20px;\">Adv+</span>";
    },
    ondblclick:function(){
            editor.insertContent(editor.dom.encode(flag["jADV ADJ*"]));
            editor.insertContent(editor.dom.encode(" "));
            clearmenu();
      }
  });

  if(prepad.length)
  {
 prepad.forEach(function (element, index, array)
 {collocate_menu2.push(element); });

 }
}
if(collocate_menu2.length){
  collocate_menu2.push({ text: '-' });
 // collocate_menu2.push({ text: 'Hide' });
 }



  //console.log(senses_filtered);
}
else
{
 selected_collocates.forEach(function (element, index, array)
 { element.COLLOCATE=element.COLLOCATE.toString().toLowerCase();
  if(element.Base==lemma)
  {
       element.Base=element.Base.toLowerCase();

   //if(element.SENSE_DISAMBIGUATION)
     {
    if(lemmatisation)
        { console.log(lemmaPOS.indexOf(element.POS));
        if(lemmaPOS.indexOf(element.POS)>=0)
 {

   // console.log(element.POS);

  example_menu=[];
  longest_match_menu=[];
  examples=[element.EXAMPLE1,element.EXAMPLE2,element.EXAMPLE3];
  element.EXAMPLES=examples;
  longest_matches={}

  element.EXAMPLES.forEach(function (element1, index, array)
 {  //var text=element1.replace(element.Base, element.Base.toUpperCase());
 //text=text.replace(element.COLLOCATE, element.COLLOCATE.toUpperCase());
 var example=convertto(element1,element.COLLOCATE,element.COLLOCATESTEM,1);
example =convertto(example,element.Base,element.BASESTEM,1);
 example_menu.push({
    text: example,
    inserttext:element1.toLowerCase(),
    onPostRender: function () {
      var text = this.getEl('text');
      text.innerHTML = example;
    },
    onclick:function(){

            editor.insertContent(editor.dom.encode(element1.toLowerCase()));
            editor.insertContent(editor.dom.encode(" "));

            clearmenu();
             //startSpellchecking();


      }
  });
 });

 example_menu.push({ text: '-' });
 /*
  example_menu.push({
    text: (editor.plugins.fullscreen.isFullscreen())?"Show more collocations":"Hide more collocations",
    onclick:function(){

                   //if(editor.plugins.fullscreen.isFullscreen())
        editor.execCommand('mceFullScreen');

      }
  });
 example_menu.push({ text: '-' });*/
  example_menu.push({
    text: "** Please take care to adapt examples to your own text **",
  });

  longest_match_menu.push({
    text: element.LONGEST_COMMONEST_MATCH,
    menu:example_menu,
    onclick:function(){ clicks++;
     if (timer) clearTimeout(timer);
   timer = setTimeout(function() { //console.log('Single');
   clicks=0;}, 250);
      if(clicks==2)
          {
          //console.log(editor.dom.encode(element));
        editor.insertContent(editor.dom.encode(element.LONGEST_COMMONEST_MATCH));
        editor.insertContent(editor.dom.encode(" "));
        clicks=0;
        clearmenu();
         }
      }
  });

  example_menu.push({ text: '-' });
  /*example_menu.push({
    text: 'www.externalresource.com',
    onclick:function(){

            //editor.insertContent(editor.dom.encode(element));
            //clearmenu();
             //startSpellchecking();
             window.open('../');

      }
  });*/

 //element.EXAMPLEMENU=example_menu;
 element.LONGESTMENU= longest_match_menu;
 collocate_obj.push(element);
  collocate_menu_global[element.RELATION]={};

 if(element.EXAMPLE1){

 /* if(!flag[element.POS+element.RELATION])
    {
   flag[element.POS+element.RELATION]=element.Base+ " " +element.COLLOCATE;

    }
 */

 if(element.RELATION=="subject_of")
 {

 if(!flag[element.POS+element.RELATION])
    {
   flag[element.POS+element.RELATION]=element.Base+ " " +element.COLLOCATE;

    }


 collocate[index]=element.Base+ " " +element.COLLOCATE;
 subject_of.push({
    text: element.LONGEST_COMMONEST_MATCH,
    menu:example_menu,
    onclick:function(){ clicks++;
     if (timer) clearTimeout(timer);
   timer = setTimeout(function() { //console.log('Single');
   clicks=0;}, 250);
      if(clicks==2)
          {
          //console.log(editor.dom.encode(element));
        editor.insertContent(editor.dom.encode(element.LONGEST_COMMONEST_MATCH));
        editor.insertContent(editor.dom.encode(" "));
        clicks=0;
        clearmenu();
         }
      }
  });
  }
  else if (element.RELATION=="object_of")
  {
 collocate[index]= element.COLLOCATE+ " " +element.Base;

  if(!flag[element.POS+element.RELATION])
    {
   flag[element.POS+element.RELATION]=element.COLLOCATE+" "+element.Base ;

    }



 object_of.push({
    text: element.LONGEST_COMMONEST_MATCH,
    menu:example_menu,
    onclick:function(){ clicks++;
     if (timer) clearTimeout(timer);
   timer = setTimeout(function() { //console.log('Single');
   clicks=0;}, 250);
      if(clicks==2)
          {
          //console.log(editor.dom.encode(element));
        editor.insertContent(editor.dom.encode(element.LONGEST_COMMONEST_MATCH));
        editor.insertContent(editor.dom.encode(" "));
        clicks=0;
        clearmenu();
         }
      }
  });
  }
  else if (element.RELATION=="modifier")
  {
 collocate[index]= element.COLLOCATE+ " " +element.Base;

  if(!flag[element.POS+element.RELATION])
    {
   flag[element.POS+element.RELATION]=element.COLLOCATE+" "+element.Base ;

    }

 modifier.push({
    text: element.COLLOCATE+ " " +element.Base,
    menu:example_menu,
    onclick:function(){ clicks++;
     if (timer) clearTimeout(timer);
   timer = setTimeout(function() { //console.log('Single');
   clicks=0;}, 250);
      if(clicks==2)
          {
          //console.log(editor.dom.encode(element));
        editor.insertContent(editor.dom.encode(element.COLLOCATE+ " " +element.Base));
        editor.insertContent(editor.dom.encode(" "));
        clicks=0;
        clearmenu();
         }
      }
  });
  }
  else if(element.RELATION=="preposition"&& element.POS=="n")
  {
  collocate[index]=element.COLLOCATE_OF_PREP;

   if(!flag[element.POS+element.RELATION])
    {
   flag[element.POS+element.RELATION]=element.Base+ " " +element.COLLOCATE+" " +element.COLLOCATE_OF_PREP ;

    }

  preposition.push({
    text: element.Base+ " " +element.COLLOCATE+" " +element.COLLOCATE_OF_PREP,
    menu:example_menu,
    basecollocate:element.Base+ " " +element.COLLOCATE,
    preposition:element.COLLOCATE_OF_PREP,
    onclick:function(){ clicks++;
     if (timer) clearTimeout(timer);
   timer = setTimeout(function() { //console.log('Single');
   clicks=0;}, 250);
      if(clicks==2)
          {
          //console.log(editor.dom.encode(element));
        editor.insertContent(editor.dom.encode(element.Base+ " " +element.COLLOCATE));
        editor.insertContent(editor.dom.encode(" "));
        clicks=0;
        clearmenu();
         }
      }
  });
  }
   else if(element.RELATION=="ADV V*")
  {
  collocate[index]=element.COLLOCATE_OF_PREP;
  if(!flag[element.POS+element.RELATION])
    {
   flag[element.POS+element.RELATION]=element.COLLOCATE+ " " +element.Base;

    }
  advv.push({
//text: element.COLLOCATE+ " " +element.Base,
   	text: (element.LONGEST_COMMONEST_MATCH.length) ? 	element.LONGEST_COMMONEST_MATCH: element.COLLOCATE+ " " +element.Base, 
   	 menu:example_menu,
    onclick:function(){ clicks++;
     if (timer) clearTimeout(timer);
   timer = setTimeout(function() { //console.log('Single');
   clicks=0;}, 250);
      if(clicks==2)
          {
          //console.log(editor.dom.encode(element));
        editor.insertContent(editor.dom.encode((element.LONGEST_COMMONEST_MATCH.length) ? 	element.LONGEST_COMMONEST_MATCH: element.COLLOCATE+ " " +element.Base));
        editor.insertContent(editor.dom.encode(" "));
        clicks=0;
        clearmenu();
         }
      }
  });
  }
  else if(element.RELATION=="preposition"&& element.POS=="v")
  {
  collocate[index]=element.COLLOCATE_OF_PREP;
  if(!flag[element.POS+element.RELATION])
    {
   flag[element.POS+element.RELATION]=element.Base+ " " +element.COLLOCATE+" " +element.COLLOCATE_OF_PREP ;

    }

  prep.push({
    text: element.Base+ " " +element.COLLOCATE+" " +element.COLLOCATE_OF_PREP,
    menu:example_menu,
    onclick:function(){ clicks++;
     if (timer) clearTimeout(timer);
   timer = setTimeout(function() { //console.log('Single');
   clicks=0;}, 250);
      if(clicks==2)
          {
          //console.log(editor.dom.encode(element));
        editor.insertContent(editor.dom.encode(element.Base+ " " +element.COLLOCATE));
        editor.insertContent(editor.dom.encode(" "));
        clicks=0;
        clearmenu();
         }
      }
  });
  }
  else if(element.RELATION=="V* ADV")
  {
  collocate[index]=element.COLLOCATE_OF_PREP;

  if(!flag[element.POS+element.RELATION])
    {
   flag[element.POS+element.RELATION]=element.Base+ " " +element.COLLOCATE;

    }
  vadv.push({
    text: element.Base+ " " +element.COLLOCATE,
    menu:example_menu,
    onclick:function(){ clicks++;
     if (timer) clearTimeout(timer);
   timer = setTimeout(function() { //console.log('Single');
   clicks=0;}, 250);
      if(clicks==2)
          {
          //console.log(editor.dom.encode(element));
        editor.insertContent(editor.dom.encode(element.Base+ " " +element.COLLOCATE));
        editor.insertContent(editor.dom.encode(" "));
        clicks=0;
        clearmenu();
         }
      }
  });
  }
  else if(element.RELATION=="ADV ADJ*")
  {
  collocate[index]=element.COLLOCATE_OF_PREP;

  if(!flag[element.POS+element.RELATION])
    {
   flag[element.POS+element.RELATION]=element.COLLOCATE+ " " +element.Base;

    }

  advadj.push({
    text: element.COLLOCATE+ " " +element.Base,
    menu:example_menu,
    onclick:function(){ clicks++;
     if (timer) clearTimeout(timer);
   timer = setTimeout(function() { //console.log('Single');
   clicks=0;}, 250);
      if(clicks==2)
          {
          //console.log(editor.dom.encode(element));
        editor.insertContent(editor.dom.encode(element.COLLOCATE+ " " +element.Base));
        editor.insertContent(editor.dom.encode(" "));
        clicks=0;
        clearmenu();
         }
      }
  });
  }
  else if(element.RELATION=="preposition"&& element.POS=="j")
  {
  collocate[index]=element.COLLOCATE_OF_PREP;
  if(!flag[element.POS+element.RELATION])
    {
   flag[element.POS+element.RELATION]=element.Base+ " " +element.COLLOCATE+" " +element.COLLOCATE_OF_PREP ;

    }

  prepad.push({
    text: element.Base+ " " +element.COLLOCATE+" " +element.COLLOCATE_OF_PREP,
    menu:example_menu,
    onclick:function(){ clicks++;
     if (timer) clearTimeout(timer);
   timer = setTimeout(function() { //console.log('Single');
   clicks=0;}, 250);
      if(clicks==2)
          {
          //console.log(editor.dom.encode(element));
        editor.insertContent(editor.dom.encode(element.Base+ " " +element.COLLOCATE));
        editor.insertContent(editor.dom.encode(" "));
        clicks=0;
        clearmenu();
         }
      }
  });
  }
  else
  {
  collocate[index]=element.COLLOCATE+ " "+element.Base;
  }}

  //pos[index]=element.POS;
  //relations[index]=element.RELATION;
  //longest_matches[index]=element.LONGEST_COMMONEST_MATCH;

 }}
    else
      {

    //  console.log(lemmaPOS.indexOf(element.POS));

  example_menu=[];
  longest_match_menu=[];
  examples=[element.EXAMPLE1,element.EXAMPLE2,element.EXAMPLE3];
  element.EXAMPLES=examples;
  longest_matches={}

  element.EXAMPLES.forEach(function (element1, index, array)
 {  //var text=element1.replace(element.Base, element.Base.toUpperCase());
// text=text.replace(element.COLLOCATE, element.COLLOCATE.toUpperCase());
var example=convertto(element1,element.COLLOCATE,element.COLLOCATESTEM,1);
example =convertto(example,element.Base,element.BASESTEM,1);
 example_menu.push({
    text: example,
    inserttext:element1.toLowerCase(),
    onPostRender: function () {
      var text = this.getEl('text');
      text.innerHTML = example;
    },
    onclick:function(){

            editor.insertContent(editor.dom.encode(element1.toLowerCase()));
            editor.insertContent(editor.dom.encode(" "));

            clearmenu();
             //startSpellchecking();


      }
  });
 });

  longest_match_menu.push({
    text: element.LONGEST_COMMONEST_MATCH,
    menu:example_menu,
    onclick:function(){ clicks++;
     if (timer) clearTimeout(timer);
   timer = setTimeout(function() { //console.log('Single');
   clicks=0;}, 250);
      if(clicks==2)
          {
          //console.log(editor.dom.encode(element));
        editor.insertContent(editor.dom.encode(element.LONGEST_COMMONEST_MATCH));
        editor.insertContent(editor.dom.encode(" "));
        clicks=0;
        clearmenu();
         }
      }
  });
  example_menu.push({ text: '-' });
 /*
  example_menu.push({
    text: (editor.plugins.fullscreen.isFullscreen())?"Show more collocations":"Hide more collocations",
    onclick:function(){

                  // if(editor.plugins.fullscreen.isFullscreen())
        editor.execCommand('mceFullScreen');

      }
  });
  example_menu.push({ text: '-' });*/
   example_menu.push({
    text: "** Please take care to adapt examples to your own text **",
  });

       // example_menu.push({ text: '-' });

  /*example_menu.push({
    text: 'www.externalresource.com',
    onclick:function(){

            //editor.insertContent(editor.dom.encode(element));
            //clearmenu();
             //startSpellchecking();
             window.open('../');

      }
  });*/

 //element.EXAMPLEMENU=example_menu;
 element.LONGESTMENU= longest_match_menu;
 collocate_obj.push(element);
  collocate_menu_global[element.RELATION]={};

 if(element.EXAMPLE1){

 /* if(!flag[element.POS+element.RELATION])
    {
   flag[element.POS+element.RELATION]=element.Base+ " " +element.COLLOCATE;

    }
 */

 if(element.RELATION=="subject_of")
 {

 if(!flag[element.POS+element.RELATION])
    {
   flag[element.POS+element.RELATION]=element.Base+ " " +element.COLLOCATE;

    }


 collocate[index]=element.Base+ " " +element.COLLOCATE;
 subject_of.push({
    text: element.LONGEST_COMMONEST_MATCH,
    menu:example_menu,
    onclick:function(){ clicks++;
     if (timer) clearTimeout(timer);
   timer = setTimeout(function() { //console.log('Single');
   clicks=0;}, 250);
      if(clicks==2)
          {
          //console.log(editor.dom.encode(element));
        editor.insertContent(editor.dom.encode(element.LONGEST_COMMONEST_MATCH));
        editor.insertContent(editor.dom.encode(" "));
        clicks=0;
        clearmenu();
         }
      }
  });
  }
  else if (element.RELATION=="object_of")
  {
 collocate[index]= element.COLLOCATE+ " " +element.Base;

  if(!flag[element.POS+element.RELATION])
    {
   flag[element.POS+element.RELATION]=element.COLLOCATE+" "+element.Base ;

    }



 object_of.push({
    text: element.LONGEST_COMMONEST_MATCH,
    menu:example_menu,
    onclick:function(){ clicks++;
     if (timer) clearTimeout(timer);
   timer = setTimeout(function() { //console.log('Single');
   clicks=0;}, 250);
      if(clicks==2)
          {
          //console.log(editor.dom.encode(element));
        editor.insertContent(editor.dom.encode(element.LONGEST_COMMONEST_MATCH));
        editor.insertContent(editor.dom.encode(" "));
        clicks=0;
        clearmenu();
         }
      }
  });
  }
  else if (element.RELATION=="modifier")
  {
 collocate[index]= element.COLLOCATE+ " " +element.Base;

  if(!flag[element.POS+element.RELATION])
    {
   flag[element.POS+element.RELATION]=element.COLLOCATE+" "+element.Base ;

    }

 modifier.push({
    text: element.COLLOCATE+ " " +element.Base,
    menu:example_menu,
    onclick:function(){ clicks++;
     if (timer) clearTimeout(timer);
   timer = setTimeout(function() { //console.log('Single');
   clicks=0;}, 250);
      if(clicks==2)
          {
          //console.log(editor.dom.encode(element));
        editor.insertContent(editor.dom.encode(element.COLLOCATE+ " " +element.Base));
        editor.insertContent(editor.dom.encode(" "));
        clicks=0;
        clearmenu();
         }
      }
  });
  }
  else if(element.RELATION=="preposition"&& element.POS=="n")
  {
  collocate[index]=element.COLLOCATE_OF_PREP;

   if(!flag[element.POS+element.RELATION])
    {
   flag[element.POS+element.RELATION]=element.Base+ " " +element.COLLOCATE+" " +element.COLLOCATE_OF_PREP ;

    }

  preposition.push({
    text: element.Base+ " " +element.COLLOCATE+" " +element.COLLOCATE_OF_PREP,
    menu:example_menu,
    basecollocate:element.Base+ " " +element.COLLOCATE,
    preposition:element.COLLOCATE_OF_PREP,
    onclick:function(){ clicks++;
     if (timer) clearTimeout(timer);
   timer = setTimeout(function() { //console.log('Single');
   clicks=0;}, 250);
      if(clicks==2)
          {
          //console.log(editor.dom.encode(element));
        editor.insertContent(editor.dom.encode(element.Base+ " " +element.COLLOCATE));
        editor.insertContent(editor.dom.encode(" "));
        clicks=0;
        clearmenu();
         }
      }
  });
  }
   else if(element.RELATION=="ADV V*")
  {
  collocate[index]=element.COLLOCATE_OF_PREP;
  if(!flag[element.POS+element.RELATION])
    {
   flag[element.POS+element.RELATION]=element.COLLOCATE+ " " +element.Base;

    }
  advv.push({
//text: element.COLLOCATE+ " " +element.Base,
   	text: (element.LONGEST_COMMONEST_MATCH.length) ? 	element.LONGEST_COMMONEST_MATCH: element.COLLOCATE+ " " +element.Base,   
   	menu:example_menu,
    onclick:function(){ clicks++;
     if (timer) clearTimeout(timer);
   timer = setTimeout(function() { //console.log('Single');
   clicks=0;}, 250);
      if(clicks==2)
          {
          //console.log(editor.dom.encode(element));
        editor.insertContent(editor.dom.encode((element.LONGEST_COMMONEST_MATCH.length) ? 	element.LONGEST_COMMONEST_MATCH: element.COLLOCATE+ " " +element.Base));
        editor.insertContent(editor.dom.encode(" "));
        clicks=0;
        clearmenu();
         }
      }
  });
  }
  else if(element.RELATION=="preposition"&& element.POS=="v")
  {
  collocate[index]=element.COLLOCATE_OF_PREP;
  if(!flag[element.POS+element.RELATION])
    {
   flag[element.POS+element.RELATION]=element.Base+ " " +element.COLLOCATE+" " +element.COLLOCATE_OF_PREP ;

    }

  prep.push({
    text: element.Base+ " " +element.COLLOCATE+" " +element.COLLOCATE_OF_PREP,
    menu:example_menu,
    onclick:function(){ clicks++;
     if (timer) clearTimeout(timer);
   timer = setTimeout(function() { //console.log('Single');
   clicks=0;}, 250);
      if(clicks==2)
          {
          //console.log(editor.dom.encode(element));
        editor.insertContent(editor.dom.encode(element.Base+ " " +element.COLLOCATE));
        editor.insertContent(editor.dom.encode(" "));
        clicks=0;
        clearmenu();
         }
      }
  });
  }
  else if(element.RELATION=="V* ADV")
  {
  collocate[index]=element.COLLOCATE_OF_PREP;

  if(!flag[element.POS+element.RELATION])
    {
   flag[element.POS+element.RELATION]=element.Base+ " " +element.COLLOCATE;

    }
  vadv.push({
    text: element.Base+ " " +element.COLLOCATE,
    menu:example_menu,
    onclick:function(){ clicks++;
     if (timer) clearTimeout(timer);
   timer = setTimeout(function() { //console.log('Single');
   clicks=0;}, 250);
      if(clicks==2)
          {
          //console.log(editor.dom.encode(element));
        editor.insertContent(editor.dom.encode(element.Base+ " " +element.COLLOCATE));
        editor.insertContent(editor.dom.encode(" "));
        clicks=0;
        clearmenu();
         }
      }
  });
  }
  else if(element.RELATION=="ADV ADJ*")
  {
  collocate[index]=element.COLLOCATE_OF_PREP;

  if(!flag[element.POS+element.RELATION])
    {
   flag[element.POS+element.RELATION]=element.COLLOCATE+ " " +element.Base;

    }

  advadj.push({
    text: element.COLLOCATE+ " " +element.Base,
    menu:example_menu,
    onclick:function(){ clicks++;
     if (timer) clearTimeout(timer);
   timer = setTimeout(function() { //console.log('Single');
   clicks=0;}, 250);
      if(clicks==2)
          {
          //console.log(editor.dom.encode(element));
        editor.insertContent(editor.dom.encode(element.COLLOCATE+ " " +element.Base));
        editor.insertContent(editor.dom.encode(" "));
        clicks=0;
        clearmenu();
         }
      }
  });
  }
  else if(element.RELATION=="preposition"&& element.POS=="j")
  {
  collocate[index]=element.COLLOCATE_OF_PREP;
  if(!flag[element.POS+element.RELATION])
    {
   flag[element.POS+element.RELATION]=element.Base+ " " +element.COLLOCATE+" " +element.COLLOCATE_OF_PREP ;

    }

  prepad.push({
    text: element.Base+ " " +element.COLLOCATE+" " +element.COLLOCATE_OF_PREP,
    menu:example_menu,
    onclick:function(){ clicks++;
     if (timer) clearTimeout(timer);
   timer = setTimeout(function() { //console.log('Single');
   clicks=0;}, 250);
      if(clicks==2)
          {
          //console.log(editor.dom.encode(element));
        editor.insertContent(editor.dom.encode(element.Base+ " " +element.COLLOCATE));
        editor.insertContent(editor.dom.encode(" "));
        clicks=0;
        clearmenu();
         }
      }
  });
  }
  else
  {
  collocate[index]=element.COLLOCATE+ " "+element.Base;
  }}

  //pos[index]=element.POS;
  //relations[index]=element.RELATION;
  //longest_matches[index]=element.LONGEST_COMMONEST_MATCH;

 }
   }
  }
 });




if(subject_of.length)
{
console.log(subject_of.length);
if(subject_of.length>=8)
{
subject_of.push({ text: '-' });
subject_of.push({
    text: "More",
    onclick:function(){console.log(this);toggle('subject_of', 'block');
    if(editor.plugins.fullscreen.isFullscreen())
        editor.execCommand('mceFullScreen');
}
  });}
 collocate_menu.push({
    text: flag['nsubject_of'],
    menu: subject_of,
    relation:"+V",
    onPostRender: function () {
      var text = this.getEl('text');
      text.innerHTML = flag['nsubject_of']+"<span style=\"float:right;padding-right:20px;\">+V</span>";
    },
    ondblclick:function(){
            editor.insertContent(editor.dom.encode(flag['nsubject_of']));
            editor.insertContent(editor.dom.encode(" "));
            clearmenu();
      }
  });
 }
 if(object_of.length)
 {
//  console.log(object_of.length);
if(object_of.length>=8){
object_of.push({ text: '-' });

object_of.push({
    text: "More",
    onclick:function(){console.log(this);toggle('object_of', 'block');
    if(editor.plugins.fullscreen.isFullscreen())
        editor.execCommand('mceFullScreen');
}
  });}
   collocate_menu.push({
    text: flag['nobject_of'],
    menu: object_of,
     relation:"V+",
     onPostRender: function () {
      var text = this.getEl('text');
      text.innerHTML = flag['nobject_of']+"<span style=\"float:right;padding-right:20px;\">V+</span>";
    },
    ondblclick:function(){
            editor.insertContent(editor.dom.encode(flag['nobject_of']));
            editor.insertContent(editor.dom.encode(" "));
            clearmenu();
      }
  });
  }
  if(modifier.length)
  {
  // console.log(modifier.length);
if(modifier.length>=8){
    modifier.push({ text: '-' });

modifier.push({
    text: "More",
    onclick:function(){console.log(this);toggle('modifier', 'block');
    if(editor.plugins.fullscreen.isFullscreen())
        editor.execCommand('mceFullScreen');
}
  });}
   collocate_menu.push({
    text: flag['nmodifier'],
    menu: modifier,
    relation:"Adj+",
     onPostRender: function () {
      var text = this.getEl('text');
      text.innerHTML = flag['nmodifier']+"<span style=\"float:right;padding-right:20px;\">Adj+</span>";
    },
    ondblclick:function(){
            editor.insertContent(editor.dom.encode(flag['nmodifier']));
            editor.insertContent(editor.dom.encode(" "));
            clearmenu();
      }
  });
  }
/*
 if(preposition.length)
   collocate_menu.push({
    text: flag['npreposition'],
    menu: preposition,
    ondblclick:function(){
            editor.insertContent(editor.dom.encode(flag['npreposition']));
            clearmenu();
      }
  });
 Show prepositions one step earlier
 */
if(preposition.length)
 {
 preposition.forEach(function (element, index, array)
 {collocate_menu.push(element); });

 }
  //console.log(collocate_menu);

 if(collocate_menu.length){
 collocate_menu.push({ text: '-' });
 // collocate_menu.push({ text: 'Hide' });
  }
  var mergedverbs = (advv.length) ? advv.concat(vadv) : vadv.concat(advv);
  //console.log(mergedverbs);
//advv.concat(vadv); // Merges both arrays
  advv=mergedverbs;
  if(mergedverbs.length)
  {
  // console.log(mergedverbs.length);
if(mergedverbs.length==8)
{    mergedverbs.push({ text: '-' });

mergedverbs.push({
    text: "More",
    onclick:function(){console.log(this);toggle('ADV V*', 'block');
    if(editor.plugins.fullscreen.isFullscreen())
        editor.execCommand('mceFullScreen');
}
  });
  }
   collocate_menu1.push({
    text: (flag["vADV V*"])?flag["vADV V*"]:flag["vV* ADV"],
    menu: mergedverbs,
    relation:"Adv+",
     onPostRender: function () {
      var text = this.getEl('text');
      text.innerHTML = (flag["vADV V*"])?flag["vADV V*"]:flag["vV* ADV"]+"<span style=\"float:right;padding-right:20px;\">Adv+</span>";
    },
    ondblclick:function(){
            editor.insertContent(editor.dom.encode(flag["vADV V*"]));
            editor.insertContent(editor.dom.encode(" "));
            clearmenu();
      }
  });
  }
/*
  if(vadv.length)
  {
   console.log(vadv.length);
if(vadv.length==8)
vadv.push({
    text: "More",
    onclick:function(){console.log(this);toggle('V* ADV', 'block');
}
  });
   collocate_menu1.push({
    text: flag["vV* ADV"],
    menu: vadv,
     onPostRender: function () {
      var text = this.getEl('text');
      text.innerHTML = flag['vV* ADV']+"<span style=\"float:right;padding-right:20px;\">+V</span>";
    },
    ondblclick:function(){
            editor.insertContent(editor.dom.encode(flag["vV* ADV"]));
            editor.insertContent(editor.dom.encode(" "));
            clearmenu();
      }
  });
  }
 if(prep.length)
  collocate_menu1.push({
    text: flag["vpreposition"],
    menu: prep,
    ondblclick:function(){
            editor.insertContent(editor.dom.encode(flag["vpreposition"]));
            clearmenu();
      }
  });

  */
 if(prep.length)
  {
 prep.forEach(function (element, index, array)
 {collocate_menu1.push(element); });

 }
if(collocate_menu1.length){
  collocate_menu1.push({ text: '-' });
 // collocate_menu1.push({ text: 'Hide' });
  }

   if(advadj.length){
   collocate_menu2=[];
   console.log(advadj.length);
if(advadj.length==8){
    advadj.push({ text: '-' });

advadj.push({
    text: "More",
    onclick:function(){console.log(this);toggle('ADV ADJ*', 'block');
    if(editor.plugins.fullscreen.isFullscreen())
        editor.execCommand('mceFullScreen');
}
  });}
  collocate_menu2.push({
    text: flag["jADV ADJ*"],
    menu: advadj,
    relation:"Adv+",
     onPostRender: function () {
      var text = this.getEl('text');
      text.innerHTML = flag['jADV ADJ*']+"<span style=\"float:right;padding-right:20px;\">Adv+</span>";
    },
    ondblclick:function(){
            editor.insertContent(editor.dom.encode(flag["jADV ADJ*"]));
            editor.insertContent(editor.dom.encode(" "));
            clearmenu();
      }
  });
}
if(prepad.length)
{
prepad.forEach(function (element, index, array)
{collocate_menu2.push(element); });

}
if(collocate_menu2.length){
  collocate_menu2.push({ text: '-' });
  //collocate_menu2.push({ text: 'Hide' });
  }

}


     //if(collocate_menu.length+collocate_menu1.length+collocate_menu2.length>2)
    global$1.each(suggestions, function (suggestion,index) {
      if(index==0&&collocate_menu.length)
      {
      items.push({
        text: suggestion,
        POStext:base,
        POS:"noun",
        //icon:'media',
        menu:collocate_menu,
        onclick: function () {
         // editor.insertContent(editor.dom.encode(suggestion));
         // editor.dom.remove(spans);
          $_cef0v7jojgqkx0oz.checkIfFinished(editor, startedState, textMatcherState);
          if(suggestionsMenu !=null)
      	{
      	//suggestionsMenu.hide();
        //suggestionsMenu = null;
      	}
        }
      });
      }
      else if(index==1&&collocate_menu1.length)
      {
      items.push({
        text: suggestion,
        POStext:base,
        POS:"verb",
        menu:collocate_menu1,
        onclick: function () {
         // editor.insertContent(editor.dom.encode(suggestion));
         // editor.dom.remove(spans);
          $_cef0v7jojgqkx0oz.checkIfFinished(editor, startedState, textMatcherState);
          if(suggestionsMenu !=null)
      	{
      	//suggestionsMenu.hide();
        //suggestionsMenu = null;
      	}
        }
      });
      }
      else if(index==2&&collocate_menu2.length)
      {
      items.push({
        text: suggestion,
        POS:"adjective",
        menu:collocate_menu2,
        onclick: function () {
         // editor.insertContent(editor.dom.encode(suggestion));
         // editor.dom.remove(spans);
          $_cef0v7jojgqkx0oz.checkIfFinished(editor, startedState, textMatcherState);
          if(suggestionsMenu !=null)
      	{
      	//suggestionsMenu.hide();
        //suggestionsMenu = null;
      	}
        }
      });
      }
    });
var txt=JSON.stringify(collocate_menu);
  items.push({ text: '-' });
  /*items.push({
        text: 'Testing',
        onclick: function(){
      editor.windowManager.open({
        title: 'Additional collocates',
        body: [{
          type: 'container',
          label  : 'flow',
          layout: 'flow',
          items: [

            {type: 'label', label: 'textbox', value: txt},
           { type   : 'textbox',
            name   : 'textbox multiline',
            label  : 'textbox multiline',
            multiline : true,
            value  : txt}


          ]
        }]
      });
      console.log(collocate_menu);
    }
      });*/

    var hasDictionarySupport = lastSuggestionsState.get().hasDictionarySupport;
    if (hasDictionarySupport) {
      items.push({
        text: 'Add to Dictionary',
        onclick: function () {
          $_cef0v7jojgqkx0oz.addToDictionary(editor, pluginUrl, startedState, textMatcherState, currentLanguageState, word, spans);
        }
      });
    }
   /* items.push.apply(items, [
      {
        text: 'Ignore',
        onclick: function () {
          $_cef0v7jojgqkx0oz.ignoreWord(editor, startedState, textMatcherState, word, spans);
        }
      },
      {
        text: 'Ignore all',
        onclick: function () {
          $_cef0v7jojgqkx0oz.ignoreWord(editor, startedState, textMatcherState, word, spans, true);
        }
      }
    ]);*/
    if(items.length>2)
    {
    suggestionsMenu = global$5.create('menu', {
      items: items,
      context: 'contextmenu',
      onautohide: function (e) {
        if (e.target.className.indexOf('spellchecker') !== -1) {
          e.preventDefault();
        }
      },
      onhide: function () {
        //suggestionsMenu.remove();
        //suggestionsMenu = null;
      }
    });
	visobj=items;
    }
    else
    {

    if(collocate_menu.length)
    visobj=collocate_menu;
    else if (collocate_menu1.length)
    visobj=collocate_menu1;
    else if (collocate_menu2.length)
    visobj=collocate_menu2;

    suggestionsMenu = global$5.create('menu', {
      items: visobj,
      context: 'contextmenu',
      onautohide: function (e) {
        if (e.target.className.indexOf('spellchecker') !== -1) {
          e.preventDefault();
        }
      },
      onhide: function () {
        //suggestionsMenu.remove();
        //suggestionsMenu = null;
      }
    });        }
    suggestionsMenu.renderTo(document.body);
   if(dropdown==0)
    suggestionsMenu.hide();
   // console.log(JSON.stringify(visobj));
    //console.log(moreobj);
collocaidVis.base(base,visobj, "", {
  insertPhrase: (res) => {editor.insertContent(editor.dom.encode(`${res}  `))},
  insertExample: (res) => {editor.insertContent(editor.dom.encode(`${res}  `))},
  showMore: (res) => {console.log('more')}
}, moreobj);

    var pos = global$4.DOM.getPos(editor.getContentAreaContainer());
    var targetPos = editor.dom.getPos(spans[0]);
    //tinyMCE.activeEditor.focus();
    var root = editor.dom.getRoot();
    if (root.nodeName === 'BODY') {
      targetPos.x -= root.ownerDocument.documentElement.scrollLeft || root.scrollLeft;
      targetPos.y -= root.ownerDocument.documentElement.scrollTop || root.scrollTop;
    } else {
      targetPos.x -= root.scrollLeft;
      targetPos.y -= root.scrollTop;
    }
    pos.x += targetPos.x;
    pos.y += targetPos.y;
    suggestionsMenu.moveTo(pos.x, pos.y + spans[0].offsetHeight);
    //console.log(suggestionsMenu);
  };
  var setup = function (editor, pluginUrl, lastSuggestionsState, startedState, textMatcherState, currentLanguageState) {
    editor.on('click', function (e) {
      var target = e.target;
      var lemma;
      if (target.className === 'mce-spellchecker-word') {
        e.preventDefault();
        var spans = $_cef0v7jojgqkx0oz.findSpansByIndex(editor, $_cef0v7jojgqkx0oz.getElmIndex(target));
        if (spans.length > 0) {
          var rng = editor.dom.createRng();
          rng.setStartBefore(spans[0]);
          rng.setEndAfter(spans[spans.length - 1]);
          editor.selection.setRng(rng);
      	 lemma= allwords[dbwords.indexOf(target.getAttribute('data-mce-word').toLowerCase())].Base;
      	// pos=allwords[dbwords.indexOf(lemma)].Base;
          showSuggestions(editor, pluginUrl, lastSuggestionsState, startedState, textMatcherState, currentLanguageState, lemma, spans);
      }
      }
      else
      {
      	clearmenu(); //Remove suggestions menu
      	//suggestionsMenu.remove();
        //suggestionsMenu = null;
      }
    });
  };
  var $_g26qoojwjgqkx0q1 = { setup: setup };

  global.add('spellchecker', function (editor, pluginUrl) {
    if ($_5fa0uxjljgqkx0oq.hasProPlugin(editor) === false) {
      var startedState = Cell(false);
      var currentLanguageState = Cell($_cklfqgjnjgqkx0ou.getLanguage(editor));
      var textMatcherState = Cell(null);
      var lastSuggestionsState = Cell(null);
      $_8x3bpjjvjgqkx0px.register(editor, pluginUrl, startedState, textMatcherState, currentLanguageState, lastSuggestionsState);
      $_g26qoojwjgqkx0q1.setup(editor, pluginUrl, lastSuggestionsState, startedState, textMatcherState, currentLanguageState);
      $_3adfryjujgqkx0pl.register(editor, pluginUrl, startedState, textMatcherState, lastSuggestionsState, currentLanguageState);
      return $_44cb15jmjgqkx0os.get(editor, startedState, lastSuggestionsState, textMatcherState, currentLanguageState, pluginUrl);
    }
  });
  function Plugin () {
  }

  return Plugin;

}());
})();
