
var debug = true;

// Log
function log(msg) {
  // if (debug) console.log(msg);
}

// React
const React = window.React;
const { useEffect } = React;

// Styled components
const styled = window.styled;
const { css } = styled;

const Wrapper = styled.div`
  width: 100%;
  border: solid 1px #dddddd;
  height: 100%;
  overflow: auto;
  padding: 0px 15px 15px 15px;
  font-family: Verdana, Arial, Helvetica, sans-serif;
  font-size: 14px;
`;

const StyledTreeView = styled.ul`
  list-style-type: none;
  margin: auto;
  padding: 0px;

  li {
    padding: 2px 0px;
    line-height: 1.2em;
  }

  .caret {
    user-select: none;

    &:hover {
      cursor: pointer;
    }
  }

  span.caret::before {
    content: "\\25B6";
    color: black;
    display: inline-block;
    margin-right: 5px;
    font-size: 0.8em;
  }

  span.caret-blue::before {
    content: "\\25B6";
    color: blue;
    display: inline-block;
    margin-right: 5px;
    font-size: 0.8em;
  }

  span.caret-down::before {
    transform: rotate(90deg);
  }

  ul {
    list-style-type: none;
  }

  ul.nested {
    margin: 4px 0px 0px 0px;
    display: none;
    padding: 0px 0px 0px 16px;
  }

  ul.active {
    display: block;
  }

  .morelist {
    padding-top: 0px;

    & + span {
      padding: 0px;
    }

    li {
      span:first-child {
        padding-left: 0px;
      }
      span:last-child {
        color: black;
        text-decoration: none;
      }
    }
  }
`;

const TreeViewExample = styled.li`
  display: flex;

  span.bullet::before {
      content: "-";
      color: black;
      display: inline-block;
      margin-right: 5px;
      font-size: 0.8em;
    }
  }
`;

const TreeViewExampleText = styled.span`
  padding: 0px 4px;

  &:hover {
    cursor: pointer;
    background-color: #eee;
    border-radius: 2px;
  }
`;

const StyledTreeViewMore = styled.li`
  padding: 2px 0px;

  span.caret::before {
    content: "\\25B6";
    color: transparent;
    display: inline-block;
    margin-right: 5px;
    font-size: 0.8em;
    display: none;
  }

  span:not(.caret) {
    cursor: pointer;
    ${"" /* padding: 0px 4px; */}
    color: blue;
    text-decoration: underline;
  }
  ${"" /* span:not(.hoverable) {
    cursor: pointer;
    padding: 0px 4px;
    color: black;
    text-decoration: none;
  } */}
`;

const TreeViewMore = ({ morelist, actions }) => {
  const [showMoreList, setShowMoreList] = React.useState(false);

  return (
    <StyledTreeViewMore>
      <MoreList items={morelist} show={showMoreList} actions={actions} />
      <span
        onClick={() => {
          setShowMoreList(!showMoreList);
        }}
      >
        {showMoreList ? "Show Less" : "Show More"}
      </span>
    </StyledTreeViewMore>
  );
};

const StyledMoreList = styled.ul`
  padding-left: 0px;
  display: ${(props) => (props.show ? "block" : "none")};

  span.caret-blue::before {
    content: "\\25B6";
    color: blue;
    display: inline-block;
    margin-right: 5px;
    font-size: 0.8em;
  }

  li {
    span:first-child {
      padding-left: 0px;
    }
    span:last-child {
      color: black;
      text-decoration: none;
    }
  }
`;

const MoreList = ({ items, show, actions }) => {
  return (
    <StyledMoreList show={show} className="morelist">
      {items.map((el, i) => (
        <li key={i}>
          <span className="caret-blue" onClick={() => window.open(el.url)} />
          <TreeViewItem
            className="hoverable"
            onClick={() => {
              actions.insertExample(el.text);
            }}
          >
            {el.text}
          </TreeViewItem>
        </li>
        /* <TreeViewExample key={i}>
          <span className="bullet"></span>
          <TreeViewExampleText
            onClick={() => {
              actions.insertExample(el.text);
            }}
            dangerouslySetInnerHTML={{ __html: el.text }}
          />
        </TreeViewExample> */
      ))}
    </StyledMoreList>
  );
};

const TreeViewItem = styled.span`
  padding: 0px 4px;

  &.hoverable:hover {
    cursor: pointer;
    background-color: #eee;
    border-radius: 2px;
  }
`;

const TreeViewRelation = styled.span`
  background-color: #ddd;
  border-radius: 2px;
  margin-left: 5px;
  padding: 0px 4px;
  font-size: 1em;
  color: #333;
`;

const TreeViewItemBrackets = styled.span`
  color: #999;
  font-style: italic;
  margin-left: 5px;
`;

const Base = styled.p`
  margin: 0px 0px 5px 0px;
  font-weight: bold;
`;

const Context = styled.p`
  margin: 0px 0px 10px 0px;
  font-style: italic;
`;

const StyledVisChooser = styled.div`
  margin-bottom: 8px;
  padding-top: 8px;
  padding-bottom: 8px;
  border-bottom: solid 1px #ccc;
  overflow: auto;
`;

const Label = styled.label`
  margin-right: 5px;
  margin-bottom: 0px;
  line-height: 27px;
`;

const Form = styled.form`
  float: left;
`;

const Close = styled.div`
  float: right;
  cursor: pointer;
  height: 26px;
  font-size: 1.2em;
  font-weight: bold;
  padding: 0px 10px;
  &:hover {
    background-color: #eee;
    border-radius: 2px;
  }
`;

const Placeholder = styled.div`
  height: 100%;
  display: flex;

  p {
    margin: auto;
  }
`;

const SuggestionExample = styled.span`
  border-bottom: 1px dashed #019802;
`;

// Get an appropriate more array
const getMoreArray = (moreArray, relation) => {
  switch (relation) {
    // +V subject of
    case "+V":
      return moreArray.filter((el) => el.submenu === "subject_of");
    // V+ object of
    case "V+":
      return moreArray.filter((el) => el.submenu === "object_of");
    // ADJ+ modifier
    case "Adj+":
      return moreArray.filter((el) => el.submenu === "modifier");
    default:
      return [];
  }
};

// Collocaid Vis :: Tree View
class TreeView extends React.Component {
  buildTree() {
    var tree = parseSubTree(
      this.props.base,
      this.props.baseObject,
      this.props.actions,
      this.props.moreArray
    );

    function parseSubTree(base, subTree, actions, moreArray = [], relation) {
      let items = subTree.map((el, i, arr) => {
        if (el.hasOwnProperty("menu")) {
          let hasRelation = el.hasOwnProperty("relation");
          let subTreeRelation = hasRelation ? el.relation : null;
          return (
            <SubTree
              key={i}
              i={i}
              el={el}
              base={base}
              parseSubTree={parseSubTree}
              actions={actions}
              moreArray={moreArray}
              relation={subTreeRelation}
            />
          );
        } else if (el.text === "More") {
          return (
            <TreeViewMore
              key={i}
              morelist={getMoreArray(moreArray, relation)}
              actions={actions}
            />
          );
        } else if (el.text !== "-" && !el.text.includes("**")) {
          return (
            <TreeViewExample key={i}>
              <span className="bullet"></span>
              <TreeViewExampleText
                onClick={() => {
                  actions.insertExample(el.inserttext);
                }}
                dangerouslySetInnerHTML={{ __html: el.text }}
              />
            </TreeViewExample>
          );
        }
      });

      return items;
    }

    return tree;
  }

  render() {
    return <StyledTreeView>{this.buildTree()}</StyledTreeView>;
  }
}

// Collocaid Vis :: Tree View / SubTree
class SubTree extends React.Component {
  constructor(props) {
    super(props);

    this.state = {
      active: false,
      prevBase: "",
    };

    this.toggleVisibility = this.toggleVisibility.bind(this);
  }

  static getDerivedStateFromProps(props, state) {
    if (props.base !== state.prevBase) {
      return {
        active: false,
        prevBase: props.base,
      };
    }
    return null;
  }

  toggleVisibility() {
    this.setState((prevState) => ({
      active: !prevState.active,
    }));
  }

  render() {
    const { i, el, parseSubTree, actions, moreArray, relation } = this.props;

    let visibility = this.state.active ? "active nested" : "nested";
    let caret = this.state.active ? "caret caret-down" : "caret";

    let hasSense = el.hasOwnProperty("sense");
    let hasPreposition = el.hasOwnProperty("preposition");
    let hasPOS = el.hasOwnProperty("POS");

    let text = hasSense
      ? el.lemma
      : hasPreposition
      ? el.basecollocate
      : hasPOS
      ? el.POStext
      : el.text;
    let brackets = hasSense
      ? `(${el.sense})`
      : hasPreposition
      ? el.preposition
      : null;

    let hoverable = hasSense || hasPOS ? null : "hoverable";
    let clickable =
      hasSense || hasPOS
        ? null
        : () => {
            actions.insertPhrase(text);
          };

    return (
      <li key={i}>
        <span className={caret} onClick={this.toggleVisibility} />
        <TreeViewItem className={hoverable} onClick={clickable}>
          {text}
        </TreeViewItem>
        {brackets ? (
          <TreeViewItemBrackets>{brackets}</TreeViewItemBrackets>
        ) : null}
        {el.POS || el.relation ? (
          <TreeViewRelation>{el.POS || el.relation}</TreeViewRelation>
        ) : null}
        <ul className={visibility}>
          {parseSubTree(this.props.base, el.menu, actions, moreArray, relation)}
        </ul>
      </li>
    );
  }
}

const FanContainer = styled.div`
  overflow: auto;
  width: max-content;
`;

const FanLeftColumn = styled.div`
  float: left;
  text-align: right;

  a {
    float: right;
  }
`;

const FanRightColumn = styled.div`
  float: left;

  a {
    float: left;
  }
`;

const CollocateRelation = styled.p`
  margin-top: 0px;
  margin: 10px 0px 15px 0px;
  height: 20px;
  line-height: 20px;
`;

const CollocateList = styled.ul(
  () => css`
    padding: 0px;
    margin: 0px;
    list-style-type: none;
    overflow: auto;
  `
);

const CollocateListItem = styled.li`
  padding: 0px;
`;

const Collocate = styled.a`
  display: block;
  clear: both;
  text-decoration: none;
  color: #000;
  height: 20px;
  line-height: 20px;
  padding: 0px 4px;

  &:hover {
    cursor: pointer;
    background-color: #eee;
    border-radius: 2px;
  }
`;

const CollocateArrowsOut = styled.div(
  ({ count }) => css`
  float: left;
  width: 25px;
  height: 160px;
  background-image: url("dist/img/collocate-arrows-out-${count}.png");
  background-size: 100%;
  background-repeat: no-repeat;
  margin: 45px 5px 0px 5px;
`
);

const CollocateArrowsIn = styled.div(
  ({ count }) => css`
  float: left;
  width: 25px;
  height: 160px;
  background-image: url("dist/img/collocate-arrows-in-${count}.png");
  background-size: 100%;
  background-repeat: no-repeat;
  margin: 45px 5px 0px 5px;
`
);

const BaseWord = styled.div`
  float: left;
  margin-top: 45px;
  height: 160px;
  line-height: 160px;
  font-weight: bold;
`;

// Collocaid Vis :: Fan View
const FanView = (props) => {
  const [Fan, setFan] = React.useState(null);
  // const [hasMultipleSenses, setHasMultipleSenses] = React.useState(null);
  const [senseList, setSenseList] = React.useState([]);
  const { base, baseObject, actions, moreArray } = props;

  React.useEffect(() => {
    if (baseObject.length !== 0) {
      // baseObject is not empty
      if (baseObject[0].hasOwnProperty("POS") && baseObject[0].POS === "noun") {
        // has POS and first entry is noun
        checkForSense(baseObject[0]);
      } else {
        // no POS (is either verb or noun)
        checkForSense({ menu: [...baseObject] });
      }
    } else {
      // Fan view unavailable
      setFan(null);
    }

    function checkForSense(noun) {
      if (noun.menu[0].hasOwnProperty("sense")) {
        handleMultipleSenses(noun);
      } else {
        // does not have sense
        if (noun.menu[0].hasOwnProperty("relation")) {
          setSenseList([]);
          // has relation
          if (
            noun.menu.filter(
              (el) => el.relation === "Adj+" || el.relation === "+V"
            ).length === 2
          ) {
            // Fan view available
            let subject = noun.menu.filter((el) => el.relation === "+V")[0];
            let modifier = noun.menu.filter((el) => el.relation === "Adj+")[0];

            generateFan(base, subject, modifier);
          } else {
            // Fan view unavailable
            setFan(null);
          }
        } else {
          // Fan view unavailable
          setFan(null);
        }
      }
    }

    function handleMultipleSenses(noun) {
      let tempSenseList = [];

      noun.menu.forEach((n, ni) => {
        if (noun.menu[ni].hasOwnProperty("menu")) {
          if (noun.menu[ni].menu[0].hasOwnProperty("relation")) {
            // has relation
            if (
              noun.menu[ni].menu.filter(
                (el) => el.relation === "Adj+" || el.relation === "+V"
              ).length === 2
            ) {
              // Fan view available
              let subject = noun.menu[ni].menu.filter(
                (el) => el.relation === "+V"
              )[0];
              let modifier = noun.menu[ni].menu.filter(
                (el) => el.relation === "Adj+"
              )[0];

              tempSenseList.push({
                noun: noun.menu[ni],
                generateFan: () => generateFan(base, subject, modifier),
              });
            } else {
              // Fan view unavailable
              setFan(null);
            }
          } else {
            // Fan view unavailable
            setFan(null);
          }
        }
      });

      if (tempSenseList.length === 1) {
        tempSenseList[0].generateFan();
      } else {
        setSenseList(tempSenseList);
      }
    }
  }, [base]);

  function generateFan(base, subject, modifier) {
    let modifiers = 0;
    let subjects = 0;
    let subjectsLong = 0;
    let subjectsLongEls = [];

    const modifierList = modifier.menu.slice(0, 8).map((el, i) => {
      modifiers++;
      return (
        <Collocate
          key={`modifier${i}`}
          onClick={() => actions.insertExample(el.text)}
        >
          {el.text.slice(0, el.text.length - base.length)}
        </Collocate>
      );
    });

    const subjectList = subject.menu.slice(0, 8).map((el, i) => {
      if (
        el.text.startsWith(base) &&
        el.text.slice(base.length, el.text.length).startsWith(" ")
      ) {
        subjects++;
        return (
          <Collocate
            key={`subject${i}`}
            onClick={() => actions.insertExample(el.text)}
          >
            {el.text.slice(base.length + 1, el.text.length)}
          </Collocate>
        );
      } else {
        subjectsLong++;
        subjectsLongEls.push(
          <Collocate
            key={`subject${i}`}
            onClick={() => actions.insertExample(el.text)}
          >
            <span style={{ fontStyle: "italic", color: "#777777" }}>
              {el.text}
            </span>
          </Collocate>
        );
        return null;
      }
    });

    const modifierMoreList =
      modifier.menu.some((el) => el.text === "More") &&
      moreArray !== undefined ? (
        <TreeViewMore
          morelist={getMoreArray(moreArray, "Adj+")}
          actions={actions}
        />
      ) : null;

    const subjectMoreList =
      subject.menu.some((el) => el.text === "More") &&
      moreArray !== undefined ? (
        <TreeViewMore
          morelist={getMoreArray(moreArray, "+V")}
          actions={actions}
        />
      ) : null;

    setFan(() => (
      <FanContainer>
        <FanLeftColumn>
          <CollocateRelation>
            {modifier.menu[0].text} <TreeViewRelation>Adj+</TreeViewRelation>
          </CollocateRelation>
          <CollocateList>{modifierList}</CollocateList>
          <CollocateList>{modifierMoreList}</CollocateList>
        </FanLeftColumn>
        <CollocateArrowsIn count={modifiers} />
        <BaseWord>{base}</BaseWord>
        <CollocateArrowsOut count={subjects} />
        <FanRightColumn>
          <CollocateRelation>
            {subject.menu[0].text} <TreeViewRelation>+V</TreeViewRelation>
          </CollocateRelation>
          <CollocateList>{subjectList}</CollocateList>
          <CollocateList>{subjectsLongEls}</CollocateList>
          <CollocateList>{subjectMoreList}</CollocateList>
        </FanRightColumn>
      </FanContainer>
    ));
  }

  return (
    <React.Fragment>
      {senseList.length !== 0 && (
        <React.Fragment>
          <p>Choose a sense:</p>
          <ul>
            {senseList.map((el, i) => (
              <li
                key={i}
                onClick={el.generateFan}
                style={{ width: "max-content" }}
              >
                <Collocate>{el.noun.sense}</Collocate>
              </li>
            ))}
          </ul>
        </React.Fragment>
      )}
      {Fan || senseList.length !== 0 ? (
        Fan
      ) : (
        <span>Fan view unavailable for {base}</span>
      )}
    </React.Fragment>
  );
};

// Collocaid Vis :: Vis Chooser
class VisChooser extends React.Component {
  render() {
    return (
      <StyledVisChooser>
        <Form>
          {/* <Label htmlFor="vis">Tree View</Label> */}
          <Label htmlFor="vis">Visualization:</Label>
          <select id="vis" name="vis" onChange={this.props.actions.setVis}>
            <option defaultValue="treeview" value="treeview">
              Tree View
            </option>
            <option value="fanview">Fan View</option>
            {/* <option value="pathview">Path View</option> */}
            {/* <option value="tileview">Tile View</option> */}
          </select>
        </Form>
        <Close
          onClick={() => {
            document.querySelector("#collocaid-vis").style.display = "none";
            document.querySelector("#container").style.width = "1000px";
            document.querySelector("#container").style.marginLeft = "auto";
            document.querySelector("#container").style.marginRight = "auto";
          }}
        >
          ⨉
        </Close>
      </StyledVisChooser>
    );
  }
}

// Collocaid Vis
class CollocaidVis extends React.Component {
  constructor(props) {
    super(props);

    this.initialState = {
      base: "",
      baseObject: [],
      context: "",
      actions: {},
      moreArray: [],
      vis: "treeview",
    };

    this.state = { ...this.initialState };

    this.renderCount = 0;

    this.setVis = this.setVis.bind(this);
  }

  componentDidMount() {
    document.body.style.margin = 0;
  }

  base(base, baseObject, context, actions, moreArray) {
    if (baseObject !== undefined) {
      this.setState(() => ({
        base,
        baseObject,
        context,
        actions,
        moreArray,
      }));
      log({ base, baseObject, context, actions, moreArray });
    }
  }

  setVis(e) {
    e.persist();
    e.target.value !== this.state.vis
      ? this.setState(() => ({
          vis: e.target.value,
        }))
      : null;
  }

  render() {
    this.renderCount++;
    log(`Render: ${this.renderCount}`);

    let vis;

    switch (this.state.vis) {
      case "treeview":
        vis = (
          <TreeView
            base={this.state.base}
            baseObject={this.state.baseObject}
            actions={this.state.actions}
            moreArray={this.state.moreArray}
          />
        );
        break;
      case "fanview":
        vis = (
          <FanView
            base={this.state.base}
            baseObject={this.state.baseObject}
            actions={this.state.actions}
            moreArray={this.state.moreArray}
          />
        );
        break;
      case "pathview":
        vis = <div>Path View</div>;
        break;
      case "tileview":
        vis = <div>Tile View</div>;
        break;
    }

    return (
      <Wrapper>
        {this.state.base ? (
          <React.Fragment>
            <VisChooser
              actions={{
                setVis: this.setVis,
              }}
            />

            <Base>{this.state.base}</Base>
            <Context>{this.state.context}</Context>

            {vis}
          </React.Fragment>
        ) : (
          <Placeholder>
            <p>
              Click a{" "}
              <SuggestionExample>collocation suggestion</SuggestionExample> to
              begin.
            </p>
            <Close
              onClick={() => {
                document.querySelector("#collocaid-vis").style.display = "none";
              }}
            >
              ⨉
            </Close>
          </Placeholder>
        )}
      </Wrapper>
    );
  }
}

var collocaidVis = ReactDOM.render(
  <CollocaidVis />,
  document.getElementById("collocaid-vis")
);
